# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class TreesApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def batch_move_nodes_to_parents(
        self,
        **kwargs: Any,
    ) -> ItemBatchOutputV1: ...

    def batch_move_nodes_to_parents_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_tree(
        self,
        **kwargs: Any,
    ) -> AssetGroupOutputV1: ...

    def create_tree_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_all_tree_types(
        self,
        **kwargs: Any,
    ) -> ItemPreviewListV1: ...

    def get_all_tree_types_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_tree(
        self,
        **kwargs: Any,
    ) -> AssetTreeOutputV1: ...

    def get_tree_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_tree_root_nodes(
        self,
        **kwargs: Any,
    ) -> AssetTreeOutputV1: ...

    def get_tree_root_nodes_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def move_nodes_to_parent(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def move_nodes_to_parent_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def move_nodes_to_root_of_tree(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def move_nodes_to_root_of_tree_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def rebuild_search_index(
        self,
        **kwargs: Any,
    ) -> None: ...

    def rebuild_search_index_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def remove_node_from_tree(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def remove_node_from_tree_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def scale_across_tree(
        self,
        **kwargs: Any,
    ) -> ScaleAcrossTreeOutputV1: ...

    def scale_across_tree_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def treemap(
        self,
        **kwargs: Any,
    ) -> TreemapOutputV1: ...

    def treemap_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_tree(
        self,
        **kwargs: Any,
    ) -> AssetGroupOutputV1: ...

    def update_tree_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
