# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ThresholdOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _is_generated: Optional[bool]
    _item: Optional[ItemPreviewV1]
    _priority: Optional[PriorityV1]
    _value: Optional[ScalarValueOutputV1]


    def __init__(
        self,
        is_generated: Optional[bool] = None,
        item: Optional[ItemPreviewV1] = None,
        priority: Optional[PriorityV1] = None,
        value: Optional[ScalarValueOutputV1] = None,
    ) -> None: ...

    @property
    def is_generated(self) -> Optional[bool]: ...

    @is_generated.setter
    def is_generated(self, is_generated: Optional[bool]) -> None: ...

    @property
    def item(self) -> Optional[ItemPreviewV1]: ...

    @item.setter
    def item(self, item: Optional[ItemPreviewV1]) -> None: ...

    @property
    def priority(self) -> Optional[PriorityV1]: ...

    @priority.setter
    def priority(self, priority: Optional[PriorityV1]) -> None: ...

    @property
    def value(self) -> Optional[ScalarValueOutputV1]: ...

    @value.setter
    def value(self, value: Optional[ScalarValueOutputV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
