# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class SchedulableAdminOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _average_run_time: int
    _content_count: int
    _document_id: Optional[str]
    _id: str
    _is_notification_configured: Optional[bool]
    _last_run_time: Optional[str]
    _last_updated: str
    _last_viewed_at: Optional[str]
    _name: str
    _next_run_time: Optional[str]
    _owner: Optional[str]
    _schedulable_type: str
    _schedules: Optional[List[str]]
    _status_message: Optional[str]
    _topic_id: Optional[str]
    _total_run_time: int
    _workbook: Optional[SchedulableWorkbookOutputV1]


    def __init__(
        self,
        average_run_time: Optional[int] = None,
        content_count: Optional[int] = None,
        document_id: Optional[str] = None,
        id: Optional[str] = None,
        is_notification_configured: Optional[bool] = None,
        last_run_time: Optional[str] = None,
        last_updated: Optional[str] = None,
        last_viewed_at: Optional[str] = None,
        name: Optional[str] = None,
        next_run_time: Optional[str] = None,
        owner: Optional[str] = None,
        schedulable_type: Optional[str] = None,
        schedules: Optional[List[str]] = None,
        status_message: Optional[str] = None,
        topic_id: Optional[str] = None,
        total_run_time: Optional[int] = None,
        workbook: Optional[SchedulableWorkbookOutputV1] = None,
    ) -> None: ...

    @property
    def average_run_time(self) -> int: ...

    @average_run_time.setter
    def average_run_time(self, average_run_time: int) -> None: ...

    @property
    def content_count(self) -> int: ...

    @content_count.setter
    def content_count(self, content_count: int) -> None: ...

    @property
    def document_id(self) -> Optional[str]: ...

    @document_id.setter
    def document_id(self, document_id: Optional[str]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def is_notification_configured(self) -> Optional[bool]: ...

    @is_notification_configured.setter
    def is_notification_configured(self, is_notification_configured: Optional[bool]) -> None: ...

    @property
    def last_run_time(self) -> Optional[str]: ...

    @last_run_time.setter
    def last_run_time(self, last_run_time: Optional[str]) -> None: ...

    @property
    def last_updated(self) -> str: ...

    @last_updated.setter
    def last_updated(self, last_updated: str) -> None: ...

    @property
    def last_viewed_at(self) -> Optional[str]: ...

    @last_viewed_at.setter
    def last_viewed_at(self, last_viewed_at: Optional[str]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def next_run_time(self) -> Optional[str]: ...

    @next_run_time.setter
    def next_run_time(self, next_run_time: Optional[str]) -> None: ...

    @property
    def owner(self) -> Optional[str]: ...

    @owner.setter
    def owner(self, owner: Optional[str]) -> None: ...

    @property
    def schedulable_type(self) -> str: ...

    @schedulable_type.setter
    def schedulable_type(self, schedulable_type: str) -> None: ...

    @property
    def schedules(self) -> Optional[List[str]]: ...

    @schedules.setter
    def schedules(self, schedules: Optional[List[str]]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def topic_id(self) -> Optional[str]: ...

    @topic_id.setter
    def topic_id(self, topic_id: Optional[str]) -> None: ...

    @property
    def total_run_time(self) -> int: ...

    @total_run_time.setter
    def total_run_time(self, total_run_time: int) -> None: ...

    @property
    def workbook(self) -> Optional[SchedulableWorkbookOutputV1]: ...

    @workbook.setter
    def workbook(self, workbook: Optional[SchedulableWorkbookOutputV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
