# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class SendEmailInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _to_emails: List[SendEmailContactV1]
    _cc_emails: List[SendEmailContactV1]
    _bcc_emails: List[SendEmailContactV1]
    _subject: str
    _content: str
    _attachments: List[SendEmailAttachmentV1]
    _reply_to: Optional[List[SendEmailContactV1]]


    def __init__(
        self,
        to_emails: Optional[List[SendEmailContactV1]] = None,
        cc_emails: Optional[List[SendEmailContactV1]] = None,
        bcc_emails: Optional[List[SendEmailContactV1]] = None,
        subject: Optional[str] = None,
        content: Optional[str] = None,
        attachments: Optional[List[SendEmailAttachmentV1]] = None,
        reply_to: Optional[List[SendEmailContactV1]] = None,
    ) -> None: ...

    @property
    def to_emails(self) -> List[SendEmailContactV1]: ...

    @to_emails.setter
    def to_emails(self, to_emails: List[SendEmailContactV1]) -> None: ...

    @property
    def cc_emails(self) -> List[SendEmailContactV1]: ...

    @cc_emails.setter
    def cc_emails(self, cc_emails: List[SendEmailContactV1]) -> None: ...

    @property
    def bcc_emails(self) -> List[SendEmailContactV1]: ...

    @bcc_emails.setter
    def bcc_emails(self, bcc_emails: List[SendEmailContactV1]) -> None: ...

    @property
    def subject(self) -> str: ...

    @subject.setter
    def subject(self, subject: str) -> None: ...

    @property
    def content(self) -> str: ...

    @content.setter
    def content(self, content: str) -> None: ...

    @property
    def attachments(self) -> List[SendEmailAttachmentV1]: ...

    @attachments.setter
    def attachments(self, attachments: List[SendEmailAttachmentV1]) -> None: ...

    @property
    def reply_to(self) -> Optional[List[SendEmailContactV1]]: ...

    @reply_to.setter
    def reply_to(self, reply_to: Optional[List[SendEmailContactV1]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
