# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class SamplesOverwriteInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _interval: Optional[IntervalV1]
    _samples: List[SampleInputV1]


    def __init__(
        self,
        interval: Optional[IntervalV1] = None,
        samples: Optional[List[SampleInputV1]] = None,
    ) -> None: ...

    @property
    def interval(self) -> Optional[IntervalV1]: ...

    @interval.setter
    def interval(self, interval: Optional[IntervalV1]) -> None: ...

    @property
    def samples(self) -> List[SampleInputV1]: ...

    @samples.setter
    def samples(self, samples: List[SampleInputV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
