# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class CalculatedTableOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'archived': 'bool',
        'column_dependencies': 'list[CalculatedTableColumnDependencyOutputV1]',
        'column_metadata': 'list[CalculatedTableColumnMetadataOutputV1]',
        'created_at': 'str',
        'creator_id': 'str',
        'description': 'str',
        'id': 'str',
        'locked': 'bool',
        'name': 'str',
        'owner_id': 'str',
        'query': 'str',
        'scoped_to': 'str',
        'updated_at': 'str'
    }

    attribute_map = {
        'archived': 'archived',
        'column_dependencies': 'columnDependencies',
        'column_metadata': 'columnMetadata',
        'created_at': 'createdAt',
        'creator_id': 'creatorId',
        'description': 'description',
        'id': 'id',
        'locked': 'locked',
        'name': 'name',
        'owner_id': 'ownerId',
        'query': 'query',
        'scoped_to': 'scopedTo',
        'updated_at': 'updatedAt'
    }

    def __init__(self, archived=None, column_dependencies=None, column_metadata=None, created_at=None, creator_id=None, description=None, id=None, locked=None, name=None, owner_id=None, query=None, scoped_to=None, updated_at=None):
        """
        CalculatedTableOutputV1 - a model defined in Swagger
        """

        self._archived = None
        self._column_dependencies = None
        self._column_metadata = None
        self._created_at = None
        self._creator_id = None
        self._description = None
        self._id = None
        self._locked = None
        self._name = None
        self._owner_id = None
        self._query = None
        self._scoped_to = None
        self._updated_at = None

        if archived is not None:
          self.archived = archived
        if column_dependencies is not None:
          self.column_dependencies = column_dependencies
        if column_metadata is not None:
          self.column_metadata = column_metadata
        if created_at is not None:
          self.created_at = created_at
        if creator_id is not None:
          self.creator_id = creator_id
        if description is not None:
          self.description = description
        if id is not None:
          self.id = id
        if locked is not None:
          self.locked = locked
        if name is not None:
          self.name = name
        if owner_id is not None:
          self.owner_id = owner_id
        if query is not None:
          self.query = query
        if scoped_to is not None:
          self.scoped_to = scoped_to
        if updated_at is not None:
          self.updated_at = updated_at

    @property
    def archived(self):
        """
        Gets the archived of this CalculatedTableOutputV1.
        Whether the calculated table is archived

        :return: The archived of this CalculatedTableOutputV1.
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """
        Sets the archived of this CalculatedTableOutputV1.
        Whether the calculated table is archived

        :param archived: The archived of this CalculatedTableOutputV1.
        :type: bool
        """

        self._archived = archived

    @property
    def column_dependencies(self):
        """
        Gets the column_dependencies of this CalculatedTableOutputV1.
        Dependencies declared for the columns returned by the query

        :return: The column_dependencies of this CalculatedTableOutputV1.
        :rtype: list[CalculatedTableColumnDependencyOutputV1]
        """
        return self._column_dependencies

    @column_dependencies.setter
    def column_dependencies(self, column_dependencies):
        """
        Sets the column_dependencies of this CalculatedTableOutputV1.
        Dependencies declared for the columns returned by the query

        :param column_dependencies: The column_dependencies of this CalculatedTableOutputV1.
        :type: list[CalculatedTableColumnDependencyOutputV1]
        """

        self._column_dependencies = column_dependencies

    @property
    def column_metadata(self):
        """
        Gets the column_metadata of this CalculatedTableOutputV1.
        Metadata describing the columns returned by the query

        :return: The column_metadata of this CalculatedTableOutputV1.
        :rtype: list[CalculatedTableColumnMetadataOutputV1]
        """
        return self._column_metadata

    @column_metadata.setter
    def column_metadata(self, column_metadata):
        """
        Sets the column_metadata of this CalculatedTableOutputV1.
        Metadata describing the columns returned by the query

        :param column_metadata: The column_metadata of this CalculatedTableOutputV1.
        :type: list[CalculatedTableColumnMetadataOutputV1]
        """

        self._column_metadata = column_metadata

    @property
    def created_at(self):
        """
        Gets the created_at of this CalculatedTableOutputV1.
        Timestamp the calculated table was created

        :return: The created_at of this CalculatedTableOutputV1.
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this CalculatedTableOutputV1.
        Timestamp the calculated table was created

        :param created_at: The created_at of this CalculatedTableOutputV1.
        :type: str
        """

        self._created_at = created_at

    @property
    def creator_id(self):
        """
        Gets the creator_id of this CalculatedTableOutputV1.
        ID of the creator

        :return: The creator_id of this CalculatedTableOutputV1.
        :rtype: str
        """
        return self._creator_id

    @creator_id.setter
    def creator_id(self, creator_id):
        """
        Sets the creator_id of this CalculatedTableOutputV1.
        ID of the creator

        :param creator_id: The creator_id of this CalculatedTableOutputV1.
        :type: str
        """

        self._creator_id = creator_id

    @property
    def description(self):
        """
        Gets the description of this CalculatedTableOutputV1.
        Description for the calculated table

        :return: The description of this CalculatedTableOutputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CalculatedTableOutputV1.
        Description for the calculated table

        :param description: The description of this CalculatedTableOutputV1.
        :type: str
        """

        self._description = description

    @property
    def id(self):
        """
        Gets the id of this CalculatedTableOutputV1.
        ID of the calculated table

        :return: The id of this CalculatedTableOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CalculatedTableOutputV1.
        ID of the calculated table

        :param id: The id of this CalculatedTableOutputV1.
        :type: str
        """

        self._id = id

    @property
    def locked(self):
        """
        Gets the locked of this CalculatedTableOutputV1.
        Whether the calculated table is locked

        :return: The locked of this CalculatedTableOutputV1.
        :rtype: bool
        """
        return self._locked

    @locked.setter
    def locked(self, locked):
        """
        Sets the locked of this CalculatedTableOutputV1.
        Whether the calculated table is locked

        :param locked: The locked of this CalculatedTableOutputV1.
        :type: bool
        """

        self._locked = locked

    @property
    def name(self):
        """
        Gets the name of this CalculatedTableOutputV1.
        Name of the calculated table

        :return: The name of this CalculatedTableOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CalculatedTableOutputV1.
        Name of the calculated table

        :param name: The name of this CalculatedTableOutputV1.
        :type: str
        """

        self._name = name

    @property
    def owner_id(self):
        """
        Gets the owner_id of this CalculatedTableOutputV1.
        ID of the owner

        :return: The owner_id of this CalculatedTableOutputV1.
        :rtype: str
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """
        Sets the owner_id of this CalculatedTableOutputV1.
        ID of the owner

        :param owner_id: The owner_id of this CalculatedTableOutputV1.
        :type: str
        """

        self._owner_id = owner_id

    @property
    def query(self):
        """
        Gets the query of this CalculatedTableOutputV1.
        The SQL query

        :return: The query of this CalculatedTableOutputV1.
        :rtype: str
        """
        return self._query

    @query.setter
    def query(self, query):
        """
        Sets the query of this CalculatedTableOutputV1.
        The SQL query

        :param query: The query of this CalculatedTableOutputV1.
        :type: str
        """

        self._query = query

    @property
    def scoped_to(self):
        """
        Gets the scoped_to of this CalculatedTableOutputV1.
        Insights Board that this calculated table is scoped to, or null for global

        :return: The scoped_to of this CalculatedTableOutputV1.
        :rtype: str
        """
        return self._scoped_to

    @scoped_to.setter
    def scoped_to(self, scoped_to):
        """
        Sets the scoped_to of this CalculatedTableOutputV1.
        Insights Board that this calculated table is scoped to, or null for global

        :param scoped_to: The scoped_to of this CalculatedTableOutputV1.
        :type: str
        """

        self._scoped_to = scoped_to

    @property
    def updated_at(self):
        """
        Gets the updated_at of this CalculatedTableOutputV1.
        Timestamp the calculated table was last updated

        :return: The updated_at of this CalculatedTableOutputV1.
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """
        Sets the updated_at of this CalculatedTableOutputV1.
        Timestamp the calculated table was last updated

        :param updated_at: The updated_at of this CalculatedTableOutputV1.
        :type: str
        """

        self._updated_at = updated_at

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, CalculatedTableOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
