# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class TileLayoutOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'height': 'int',
        'id': 'str',
        'width': 'int',
        'x': 'int',
        'y': 'int'
    }

    attribute_map = {
        'height': 'height',
        'id': 'id',
        'width': 'width',
        'x': 'x',
        'y': 'y'
    }

    def __init__(self, height=None, id=None, width=None, x=None, y=None):
        """
        TileLayoutOutputV1 - a model defined in Swagger
        """

        self._height = None
        self._id = None
        self._width = None
        self._x = None
        self._y = None

        if height is not None:
          self.height = height
        if id is not None:
          self.id = id
        if width is not None:
          self.width = width
        if x is not None:
          self.x = x
        if y is not None:
          self.y = y

    @property
    def height(self):
        """
        Gets the height of this TileLayoutOutputV1.
        The height of the tile in grid units

        :return: The height of this TileLayoutOutputV1.
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """
        Sets the height of this TileLayoutOutputV1.
        The height of the tile in grid units

        :param height: The height of this TileLayoutOutputV1.
        :type: int
        """
        if height is None:
            raise ValueError("Invalid value for `height`, must not be `None`")

        self._height = height

    @property
    def id(self):
        """
        Gets the id of this TileLayoutOutputV1.
        The unique identifier of the tile

        :return: The id of this TileLayoutOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this TileLayoutOutputV1.
        The unique identifier of the tile

        :param id: The id of this TileLayoutOutputV1.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def width(self):
        """
        Gets the width of this TileLayoutOutputV1.
        The width of the tile in grid units

        :return: The width of this TileLayoutOutputV1.
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """
        Sets the width of this TileLayoutOutputV1.
        The width of the tile in grid units

        :param width: The width of this TileLayoutOutputV1.
        :type: int
        """
        if width is None:
            raise ValueError("Invalid value for `width`, must not be `None`")

        self._width = width

    @property
    def x(self):
        """
        Gets the x of this TileLayoutOutputV1.
        The X position of the tile in the grid

        :return: The x of this TileLayoutOutputV1.
        :rtype: int
        """
        return self._x

    @x.setter
    def x(self, x):
        """
        Sets the x of this TileLayoutOutputV1.
        The X position of the tile in the grid

        :param x: The x of this TileLayoutOutputV1.
        :type: int
        """
        if x is None:
            raise ValueError("Invalid value for `x`, must not be `None`")

        self._x = x

    @property
    def y(self):
        """
        Gets the y of this TileLayoutOutputV1.
        The Y position of the tile in the grid

        :return: The y of this TileLayoutOutputV1.
        :rtype: int
        """
        return self._y

    @y.setter
    def y(self, y):
        """
        Sets the y of this TileLayoutOutputV1.
        The Y position of the tile in the grid

        :param y: The y of this TileLayoutOutputV1.
        :type: int
        """
        if y is None:
            raise ValueError("Invalid value for `y`, must not be `None`")

        self._y = y

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TileLayoutOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
