# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class RegressionOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _adjusted_r_squared: float
    _error_sum_squares: float
    _intercept: float
    _intercept_standard_error: float
    _is_uncertain: bool
    _r_squared: Optional[float]
    _regression_sum_squares: float
    _suggested_p_value_cutoff: float


    def __init__(
        self,
        adjusted_r_squared: Optional[float] = None,
        error_sum_squares: Optional[float] = None,
        intercept: Optional[float] = None,
        intercept_standard_error: Optional[float] = None,
        is_uncertain: Optional[bool] = False,
        r_squared: Optional[float] = None,
        regression_sum_squares: Optional[float] = None,
        suggested_p_value_cutoff: Optional[float] = None,
    ) -> None: ...

    @property
    def adjusted_r_squared(self) -> float: ...

    @adjusted_r_squared.setter
    def adjusted_r_squared(self, adjusted_r_squared: float) -> None: ...

    @property
    def error_sum_squares(self) -> float: ...

    @error_sum_squares.setter
    def error_sum_squares(self, error_sum_squares: float) -> None: ...

    @property
    def intercept(self) -> float: ...

    @intercept.setter
    def intercept(self, intercept: float) -> None: ...

    @property
    def intercept_standard_error(self) -> float: ...

    @intercept_standard_error.setter
    def intercept_standard_error(self, intercept_standard_error: float) -> None: ...

    @property
    def is_uncertain(self) -> bool: ...

    @is_uncertain.setter
    def is_uncertain(self, is_uncertain: bool) -> None: ...

    @property
    def r_squared(self) -> Optional[float]: ...

    @r_squared.setter
    def r_squared(self, r_squared: Optional[float]) -> None: ...

    @property
    def regression_sum_squares(self) -> float: ...

    @regression_sum_squares.setter
    def regression_sum_squares(self, regression_sum_squares: float) -> None: ...

    @property
    def suggested_p_value_cutoff(self) -> float: ...

    @suggested_p_value_cutoff.setter
    def suggested_p_value_cutoff(self, suggested_p_value_cutoff: float) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
