# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class PrecachedItemOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _cache_id: Optional[str]
    _capsule_property_infos: Optional[List[PreCachedConditionCapsulePropertyInfoV1]]
    _data_id: Optional[str]
    _last_certain_key_nanos: Optional[int]
    _max_duration_nanos: Optional[int]
    _max_interpolation_nanos: Optional[int]
    _type: Optional[str]
    _uncertainty_override_nanos: Optional[int]
    _value_uom: Optional[str]


    def __init__(
        self,
        cache_id: Optional[str] = None,
        capsule_property_infos: Optional[List[PreCachedConditionCapsulePropertyInfoV1]] = None,
        data_id: Optional[str] = None,
        last_certain_key_nanos: Optional[int] = None,
        max_duration_nanos: Optional[int] = None,
        max_interpolation_nanos: Optional[int] = None,
        type: Optional[str] = None,
        uncertainty_override_nanos: Optional[int] = None,
        value_uom: Optional[str] = None,
    ) -> None: ...

    @property
    def cache_id(self) -> Optional[str]: ...

    @cache_id.setter
    def cache_id(self, cache_id: Optional[str]) -> None: ...

    @property
    def capsule_property_infos(self) -> Optional[List[PreCachedConditionCapsulePropertyInfoV1]]: ...

    @capsule_property_infos.setter
    def capsule_property_infos(self, capsule_property_infos: Optional[List[PreCachedConditionCapsulePropertyInfoV1]]) -> None: ...

    @property
    def data_id(self) -> Optional[str]: ...

    @data_id.setter
    def data_id(self, data_id: Optional[str]) -> None: ...

    @property
    def last_certain_key_nanos(self) -> Optional[int]: ...

    @last_certain_key_nanos.setter
    def last_certain_key_nanos(self, last_certain_key_nanos: Optional[int]) -> None: ...

    @property
    def max_duration_nanos(self) -> Optional[int]: ...

    @max_duration_nanos.setter
    def max_duration_nanos(self, max_duration_nanos: Optional[int]) -> None: ...

    @property
    def max_interpolation_nanos(self) -> Optional[int]: ...

    @max_interpolation_nanos.setter
    def max_interpolation_nanos(self, max_interpolation_nanos: Optional[int]) -> None: ...

    @property
    def type(self) -> Optional[str]: ...

    @type.setter
    def type(self, type: Optional[str]) -> None: ...

    @property
    def uncertainty_override_nanos(self) -> Optional[int]: ...

    @uncertainty_override_nanos.setter
    def uncertainty_override_nanos(self, uncertainty_override_nanos: Optional[int]) -> None: ...

    @property
    def value_uom(self) -> Optional[str]: ...

    @value_uom.setter
    def value_uom(self, value_uom: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
