# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ContextCommentInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _category_id: Optional[str]
    _comment: Optional[str]
    _datum_id: Optional[str]
    _end_time: Optional[str]
    _is_pinned: Optional[bool]
    _mentions: Optional[List[MentionInputV1]]
    _source: Optional[ContextSourceInputV1]
    _start_time: Optional[str]
    _table_id: Optional[str]


    def __init__(
        self,
        category_id: Optional[str] = None,
        comment: Optional[str] = None,
        datum_id: Optional[str] = None,
        end_time: Optional[str] = None,
        is_pinned: Optional[bool] = None,
        mentions: Optional[List[MentionInputV1]] = None,
        source: Optional[ContextSourceInputV1] = None,
        start_time: Optional[str] = None,
        table_id: Optional[str] = None,
    ) -> None: ...

    @property
    def category_id(self) -> Optional[str]: ...

    @category_id.setter
    def category_id(self, category_id: Optional[str]) -> None: ...

    @property
    def comment(self) -> Optional[str]: ...

    @comment.setter
    def comment(self, comment: Optional[str]) -> None: ...

    @property
    def datum_id(self) -> Optional[str]: ...

    @datum_id.setter
    def datum_id(self, datum_id: Optional[str]) -> None: ...

    @property
    def end_time(self) -> Optional[str]: ...

    @end_time.setter
    def end_time(self, end_time: Optional[str]) -> None: ...

    @property
    def is_pinned(self) -> Optional[bool]: ...

    @is_pinned.setter
    def is_pinned(self, is_pinned: Optional[bool]) -> None: ...

    @property
    def mentions(self) -> Optional[List[MentionInputV1]]: ...

    @mentions.setter
    def mentions(self, mentions: Optional[List[MentionInputV1]]) -> None: ...

    @property
    def source(self) -> Optional[ContextSourceInputV1]: ...

    @source.setter
    def source(self, source: Optional[ContextSourceInputV1]) -> None: ...

    @property
    def start_time(self) -> Optional[str]: ...

    @start_time.setter
    def start_time(self, start_time: Optional[str]) -> None: ...

    @property
    def table_id(self) -> Optional[str]: ...

    @table_id.setter
    def table_id(self, table_id: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
