# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class TimeInterval(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _duration_time: Optional[int]
    _empty: Optional[bool]
    _end_string: Optional[str]
    _end_time: Optional[int]
    _limit: Optional[bool]
    _start_string: Optional[str]
    _start_time: Optional[int]
    _time_key: Optional[int]


    def __init__(
        self,
        duration_time: Optional[int] = None,
        empty: Optional[bool] = None,
        end_string: Optional[str] = None,
        end_time: Optional[int] = None,
        limit: Optional[bool] = None,
        start_string: Optional[str] = None,
        start_time: Optional[int] = None,
        time_key: Optional[int] = None,
    ) -> None: ...

    @property
    def duration_time(self) -> Optional[int]: ...

    @duration_time.setter
    def duration_time(self, duration_time: Optional[int]) -> None: ...

    @property
    def empty(self) -> Optional[bool]: ...

    @empty.setter
    def empty(self, empty: Optional[bool]) -> None: ...

    @property
    def end_string(self) -> Optional[str]: ...

    @end_string.setter
    def end_string(self, end_string: Optional[str]) -> None: ...

    @property
    def end_time(self) -> Optional[int]: ...

    @end_time.setter
    def end_time(self, end_time: Optional[int]) -> None: ...

    @property
    def limit(self) -> Optional[bool]: ...

    @limit.setter
    def limit(self, limit: Optional[bool]) -> None: ...

    @property
    def start_string(self) -> Optional[str]: ...

    @start_string.setter
    def start_string(self, start_string: Optional[str]) -> None: ...

    @property
    def start_time(self) -> Optional[int]: ...

    @start_time.setter
    def start_time(self, start_time: Optional[int]) -> None: ...

    @property
    def time_key(self) -> Optional[int]: ...

    @time_key.setter
    def time_key(self, time_key: Optional[int]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
