# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ReleaseNotesOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _current_release_notes: List[IssueSummaryOutputV1]
    _next_upgrade_time: Optional[str]
    _next_version: Optional[str]
    _past_release_notes: List[IssueSummaryOutputV1]
    _upcoming_release_notes: List[IssueSummaryOutputV1]


    def __init__(
        self,
        current_release_notes: Optional[List[IssueSummaryOutputV1]] = None,
        next_upgrade_time: Optional[str] = None,
        next_version: Optional[str] = None,
        past_release_notes: Optional[List[IssueSummaryOutputV1]] = None,
        upcoming_release_notes: Optional[List[IssueSummaryOutputV1]] = None,
    ) -> None: ...

    @property
    def current_release_notes(self) -> List[IssueSummaryOutputV1]: ...

    @current_release_notes.setter
    def current_release_notes(self, current_release_notes: List[IssueSummaryOutputV1]) -> None: ...

    @property
    def next_upgrade_time(self) -> Optional[str]: ...

    @next_upgrade_time.setter
    def next_upgrade_time(self, next_upgrade_time: Optional[str]) -> None: ...

    @property
    def next_version(self) -> Optional[str]: ...

    @next_version.setter
    def next_version(self, next_version: Optional[str]) -> None: ...

    @property
    def past_release_notes(self) -> List[IssueSummaryOutputV1]: ...

    @past_release_notes.setter
    def past_release_notes(self, past_release_notes: List[IssueSummaryOutputV1]) -> None: ...

    @property
    def upcoming_release_notes(self) -> List[IssueSummaryOutputV1]: ...

    @upcoming_release_notes.setter
    def upcoming_release_notes(self, upcoming_release_notes: List[IssueSummaryOutputV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
