# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class PreProvisionInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _agent_name: Optional[str]
    _machine_name: str
    _re_provisioning_allowed: Optional[bool]
    _source_address: Optional[str]


    def __init__(
        self,
        agent_name: Optional[str] = None,
        machine_name: Optional[str] = None,
        re_provisioning_allowed: Optional[bool] = False,
        source_address: Optional[str] = None,
    ) -> None: ...

    @property
    def agent_name(self) -> Optional[str]: ...

    @agent_name.setter
    def agent_name(self, agent_name: Optional[str]) -> None: ...

    @property
    def machine_name(self) -> str: ...

    @machine_name.setter
    def machine_name(self, machine_name: str) -> None: ...

    @property
    def re_provisioning_allowed(self) -> Optional[bool]: ...

    @re_provisioning_allowed.setter
    def re_provisioning_allowed(self, re_provisioning_allowed: Optional[bool]) -> None: ...

    @property
    def source_address(self) -> Optional[str]: ...

    @source_address.setter
    def source_address(self, source_address: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
