# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class CalculatedTableDataQueryInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'filter': 'Filter',
        'limit': 'int',
        'timezone': 'str'
    }

    attribute_map = {
        'filter': 'filter',
        'limit': 'limit',
        'timezone': 'timezone'
    }

    def __init__(self, filter=None, limit=None, timezone=None):
        """
        CalculatedTableDataQueryInputV1 - a model defined in Swagger
        """

        self._filter = None
        self._limit = None
        self._timezone = None

        if filter is not None:
          self.filter = filter
        if limit is not None:
          self.limit = limit
        if timezone is not None:
          self.timezone = timezone

    @property
    def filter(self):
        """
        Gets the filter of this CalculatedTableDataQueryInputV1.

        :return: The filter of this CalculatedTableDataQueryInputV1.
        :rtype: Filter
        """
        return self._filter

    @filter.setter
    def filter(self, filter):
        """
        Sets the filter of this CalculatedTableDataQueryInputV1.

        :param filter: The filter of this CalculatedTableDataQueryInputV1.
        :type: Filter
        """

        self._filter = filter

    @property
    def limit(self):
        """
        Gets the limit of this CalculatedTableDataQueryInputV1.
        Maximum number of rows to return

        :return: The limit of this CalculatedTableDataQueryInputV1.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """
        Sets the limit of this CalculatedTableDataQueryInputV1.
        Maximum number of rows to return

        :param limit: The limit of this CalculatedTableDataQueryInputV1.
        :type: int
        """

        self._limit = limit

    @property
    def timezone(self):
        """
        Gets the timezone of this CalculatedTableDataQueryInputV1.
        Timezone to use for timestamp operations (e.g. 'America/New_York')

        :return: The timezone of this CalculatedTableDataQueryInputV1.
        :rtype: str
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        """
        Sets the timezone of this CalculatedTableDataQueryInputV1.
        Timezone to use for timestamp operations (e.g. 'America/New_York')

        :param timezone: The timezone of this CalculatedTableDataQueryInputV1.
        :type: str
        """
        if timezone is None:
            raise ValueError("Invalid value for `timezone`, must not be `None`")

        self._timezone = timezone

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, CalculatedTableDataQueryInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
