# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class InstanceOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _errors: Optional[List[ModelApplicationErrorOutputV1]]
    _input_features: Optional[List[InputFeatureV1]]
    _inputs: Optional[List[ModelApplicationMappingV1]]
    _instance_id: Optional[str]
    _is_retired: Optional[bool]
    _model_container_id: Optional[str]
    _model_id: Optional[str]
    _outputs: Optional[List[InstanceOutputMappingV1]]
    _table_application_id: Optional[str]


    def __init__(
        self,
        errors: Optional[List[ModelApplicationErrorOutputV1]] = None,
        input_features: Optional[List[InputFeatureV1]] = None,
        inputs: Optional[List[ModelApplicationMappingV1]] = None,
        instance_id: Optional[str] = None,
        is_retired: Optional[bool] = None,
        model_container_id: Optional[str] = None,
        model_id: Optional[str] = None,
        outputs: Optional[List[InstanceOutputMappingV1]] = None,
        table_application_id: Optional[str] = None,
    ) -> None: ...

    @property
    def errors(self) -> Optional[List[ModelApplicationErrorOutputV1]]: ...

    @errors.setter
    def errors(self, errors: Optional[List[ModelApplicationErrorOutputV1]]) -> None: ...

    @property
    def input_features(self) -> Optional[List[InputFeatureV1]]: ...

    @input_features.setter
    def input_features(self, input_features: Optional[List[InputFeatureV1]]) -> None: ...

    @property
    def inputs(self) -> Optional[List[ModelApplicationMappingV1]]: ...

    @inputs.setter
    def inputs(self, inputs: Optional[List[ModelApplicationMappingV1]]) -> None: ...

    @property
    def instance_id(self) -> Optional[str]: ...

    @instance_id.setter
    def instance_id(self, instance_id: Optional[str]) -> None: ...

    @property
    def is_retired(self) -> Optional[bool]: ...

    @is_retired.setter
    def is_retired(self, is_retired: Optional[bool]) -> None: ...

    @property
    def model_container_id(self) -> Optional[str]: ...

    @model_container_id.setter
    def model_container_id(self, model_container_id: Optional[str]) -> None: ...

    @property
    def model_id(self) -> Optional[str]: ...

    @model_id.setter
    def model_id(self, model_id: Optional[str]) -> None: ...

    @property
    def outputs(self) -> Optional[List[InstanceOutputMappingV1]]: ...

    @outputs.setter
    def outputs(self, outputs: Optional[List[InstanceOutputMappingV1]]) -> None: ...

    @property
    def table_application_id(self) -> Optional[str]: ...

    @table_application_id.setter
    def table_application_id(self, table_application_id: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
