# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class ModelsApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def apply_model(
        self,
        **kwargs: Any,
    ) -> InstanceOutputV1: ...

    def apply_model_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def apply_model_to_table(
        self,
        **kwargs: Any,
    ) -> ModelTableApplicationOutputV1: ...

    def apply_model_to_table_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_model(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def archive_model_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_draft(
        self,
        **kwargs: Any,
    ) -> ModelOutputV1: ...

    def create_draft_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_model(
        self,
        **kwargs: Any,
    ) -> ModelOutputV1: ...

    def create_model_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_model_from_items(
        self,
        **kwargs: Any,
    ) -> ModelOutputV1: ...

    def create_model_from_items_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_model_from_table_column_definitions(
        self,
        **kwargs: Any,
    ) -> ModelOutputV1: ...

    def create_model_from_table_column_definitions_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def duplicate_model(
        self,
        **kwargs: Any,
    ) -> ModelOutputV1: ...

    def duplicate_model_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def edit_model(
        self,
        **kwargs: Any,
    ) -> ModelOutputV1: ...

    def edit_model_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def generate_column_model(
        self,
        **kwargs: Any,
    ) -> ColumnModelOutput: ...

    def generate_column_model_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_applied_model_tables(
        self,
        **kwargs: Any,
    ) -> List[TableDefinitionOutputV1]: ...

    def get_applied_model_tables_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_instance(
        self,
        **kwargs: Any,
    ) -> InstanceOutputV1: ...

    def get_instance_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_instances_for_model(
        self,
        **kwargs: Any,
    ) -> InstanceOutputPaginatedListV1: ...

    def get_instances_for_model_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_instances_for_table(
        self,
        **kwargs: Any,
    ) -> InstanceOutputPaginatedListV1: ...

    def get_instances_for_table_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_model(
        self,
        **kwargs: Any,
    ) -> ModelOutputV1: ...

    def get_model_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_models(
        self,
        **kwargs: Any,
    ) -> ModelOutputListV1: ...

    def get_models_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_table_definition_model_applications(
        self,
        **kwargs: Any,
    ) -> ModelTableApplicationsOutputListV1: ...

    def get_table_definition_model_applications_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def publish_model_version(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def publish_model_version_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def reapply_model(
        self,
        **kwargs: Any,
    ) -> InstanceOutputV1: ...

    def reapply_model_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def reapply_model_to_table(
        self,
        **kwargs: Any,
    ) -> ModelTableApplicationOutputV1: ...

    def reapply_model_to_table_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def retire_application(
        self,
        **kwargs: Any,
    ) -> TableApplicationRetiredOutputV1: ...

    def retire_application_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def retire_instance(
        self,
        **kwargs: Any,
    ) -> InstanceRetiredOutputV1: ...

    def retire_instance_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
