# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class TableModelApplicationInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _derived_column_names: List[ModelDerivedColumnNamesInputV1]
    _inputs: Optional[List[ModelApplicationMappingV1]]


    def __init__(
        self,
        derived_column_names: Optional[List[ModelDerivedColumnNamesInputV1]] = None,
        inputs: Optional[List[ModelApplicationMappingV1]] = None,
    ) -> None: ...

    @property
    def derived_column_names(self) -> List[ModelDerivedColumnNamesInputV1]: ...

    @derived_column_names.setter
    def derived_column_names(self, derived_column_names: List[ModelDerivedColumnNamesInputV1]) -> None: ...

    @property
    def inputs(self) -> Optional[List[ModelApplicationMappingV1]]: ...

    @inputs.setter
    def inputs(self, inputs: Optional[List[ModelApplicationMappingV1]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
