# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ContentOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _analysis_view_type: Optional[str]
    _asset_selection: Optional[AssetSelectionOutputV1]
    _date_range: Optional[DateRangeOutputV1]
    _description: Optional[str]
    _effective_permissions: Optional[PermissionsV1]
    _fill_to_fit: bool
    _hash_code: Optional[str]
    _height: Optional[int]
    _hide_uncertainty: bool
    _id: str
    _is_archived: Optional[bool]
    _is_redacted: Optional[bool]
    _name: str
    _react: bool
    _report: Optional[ItemPreviewV1]
    _scale: Optional[float]
    _selector: Optional[str]
    _source_workbook: Optional[str]
    _source_worksheet: Optional[str]
    _source_workstep: Optional[str]
    _status_message: Optional[str]
    _summary_type: Optional[str]
    _summary_value: Optional[str]
    _timezone: Optional[str]
    _translation_key: Optional[str]
    _type: str
    _warning: Optional[str]
    _width: Optional[int]


    def __init__(
        self,
        analysis_view_type: Optional[str] = None,
        asset_selection: Optional[AssetSelectionOutputV1] = None,
        date_range: Optional[DateRangeOutputV1] = None,
        description: Optional[str] = None,
        effective_permissions: Optional[PermissionsV1] = None,
        fill_to_fit: Optional[bool] = None,
        hash_code: Optional[str] = None,
        height: Optional[int] = None,
        hide_uncertainty: Optional[bool] = None,
        id: Optional[str] = None,
        is_archived: Optional[bool] = False,
        is_redacted: Optional[bool] = False,
        name: Optional[str] = None,
        react: Optional[bool] = None,
        report: Optional[ItemPreviewV1] = None,
        scale: Optional[float] = None,
        selector: Optional[str] = None,
        source_workbook: Optional[str] = None,
        source_worksheet: Optional[str] = None,
        source_workstep: Optional[str] = None,
        status_message: Optional[str] = None,
        summary_type: Optional[str] = None,
        summary_value: Optional[str] = None,
        timezone: Optional[str] = None,
        translation_key: Optional[str] = None,
        type: Optional[str] = None,
        warning: Optional[str] = None,
        width: Optional[int] = None,
    ) -> None: ...

    @property
    def analysis_view_type(self) -> Optional[str]: ...

    @analysis_view_type.setter
    def analysis_view_type(self, analysis_view_type: Optional[str]) -> None: ...

    @property
    def asset_selection(self) -> Optional[AssetSelectionOutputV1]: ...

    @asset_selection.setter
    def asset_selection(self, asset_selection: Optional[AssetSelectionOutputV1]) -> None: ...

    @property
    def date_range(self) -> Optional[DateRangeOutputV1]: ...

    @date_range.setter
    def date_range(self, date_range: Optional[DateRangeOutputV1]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def effective_permissions(self) -> Optional[PermissionsV1]: ...

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions: Optional[PermissionsV1]) -> None: ...

    @property
    def fill_to_fit(self) -> bool: ...

    @fill_to_fit.setter
    def fill_to_fit(self, fill_to_fit: bool) -> None: ...

    @property
    def hash_code(self) -> Optional[str]: ...

    @hash_code.setter
    def hash_code(self, hash_code: Optional[str]) -> None: ...

    @property
    def height(self) -> Optional[int]: ...

    @height.setter
    def height(self, height: Optional[int]) -> None: ...

    @property
    def hide_uncertainty(self) -> bool: ...

    @hide_uncertainty.setter
    def hide_uncertainty(self, hide_uncertainty: bool) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def is_redacted(self) -> Optional[bool]: ...

    @is_redacted.setter
    def is_redacted(self, is_redacted: Optional[bool]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def react(self) -> bool: ...

    @react.setter
    def react(self, react: bool) -> None: ...

    @property
    def report(self) -> Optional[ItemPreviewV1]: ...

    @report.setter
    def report(self, report: Optional[ItemPreviewV1]) -> None: ...

    @property
    def scale(self) -> Optional[float]: ...

    @scale.setter
    def scale(self, scale: Optional[float]) -> None: ...

    @property
    def selector(self) -> Optional[str]: ...

    @selector.setter
    def selector(self, selector: Optional[str]) -> None: ...

    @property
    def source_workbook(self) -> Optional[str]: ...

    @source_workbook.setter
    def source_workbook(self, source_workbook: Optional[str]) -> None: ...

    @property
    def source_worksheet(self) -> Optional[str]: ...

    @source_worksheet.setter
    def source_worksheet(self, source_worksheet: Optional[str]) -> None: ...

    @property
    def source_workstep(self) -> Optional[str]: ...

    @source_workstep.setter
    def source_workstep(self, source_workstep: Optional[str]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def summary_type(self) -> Optional[str]: ...

    @summary_type.setter
    def summary_type(self, summary_type: Optional[str]) -> None: ...

    @property
    def summary_value(self) -> Optional[str]: ...

    @summary_value.setter
    def summary_value(self, summary_value: Optional[str]) -> None: ...

    @property
    def timezone(self) -> Optional[str]: ...

    @timezone.setter
    def timezone(self, timezone: Optional[str]) -> None: ...

    @property
    def translation_key(self) -> Optional[str]: ...

    @translation_key.setter
    def translation_key(self, translation_key: Optional[str]) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    @property
    def warning(self) -> Optional[str]: ...

    @warning.setter
    def warning(self, warning: Optional[str]) -> None: ...

    @property
    def width(self) -> Optional[int]: ...

    @width.setter
    def width(self, width: Optional[int]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
