# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class CustomAgentOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'effective_permissions': 'PermissionsV1',
        'id': 'str',
        'meta': 'CustomAgentMetaOutputV1',
        'name': 'str',
        'owner': 'bool',
        'workflow': 'str'
    }

    attribute_map = {
        'effective_permissions': 'effectivePermissions',
        'id': 'id',
        'meta': 'meta',
        'name': 'name',
        'owner': 'owner',
        'workflow': 'workflow'
    }

    def __init__(self, effective_permissions=None, id=None, meta=None, name=None, owner=None, workflow=None):
        """
        CustomAgentOutputV1 - a model defined in Swagger
        """

        self._effective_permissions = None
        self._id = None
        self._meta = None
        self._name = None
        self._owner = None
        self._workflow = None

        if effective_permissions is not None:
          self.effective_permissions = effective_permissions
        if id is not None:
          self.id = id
        if meta is not None:
          self.meta = meta
        if name is not None:
          self.name = name
        if owner is not None:
          self.owner = owner
        if workflow is not None:
          self.workflow = workflow

    @property
    def effective_permissions(self):
        """
        Gets the effective_permissions of this CustomAgentOutputV1.

        :return: The effective_permissions of this CustomAgentOutputV1.
        :rtype: PermissionsV1
        """
        return self._effective_permissions

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions):
        """
        Sets the effective_permissions of this CustomAgentOutputV1.

        :param effective_permissions: The effective_permissions of this CustomAgentOutputV1.
        :type: PermissionsV1
        """
        if effective_permissions is None:
            raise ValueError("Invalid value for `effective_permissions`, must not be `None`")

        self._effective_permissions = effective_permissions

    @property
    def id(self):
        """
        Gets the id of this CustomAgentOutputV1.
        The ID of the custom agent

        :return: The id of this CustomAgentOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CustomAgentOutputV1.
        The ID of the custom agent

        :param id: The id of this CustomAgentOutputV1.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def meta(self):
        """
        Gets the meta of this CustomAgentOutputV1.

        :return: The meta of this CustomAgentOutputV1.
        :rtype: CustomAgentMetaOutputV1
        """
        return self._meta

    @meta.setter
    def meta(self, meta):
        """
        Sets the meta of this CustomAgentOutputV1.

        :param meta: The meta of this CustomAgentOutputV1.
        :type: CustomAgentMetaOutputV1
        """
        if meta is None:
            raise ValueError("Invalid value for `meta`, must not be `None`")

        self._meta = meta

    @property
    def name(self):
        """
        Gets the name of this CustomAgentOutputV1.
        The name of the custom agent

        :return: The name of this CustomAgentOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CustomAgentOutputV1.
        The name of the custom agent

        :param name: The name of this CustomAgentOutputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def owner(self):
        """
        Gets the owner of this CustomAgentOutputV1.

        :return: The owner of this CustomAgentOutputV1.
        :rtype: bool
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """
        Sets the owner of this CustomAgentOutputV1.

        :param owner: The owner of this CustomAgentOutputV1.
        :type: bool
        """

        self._owner = owner

    @property
    def workflow(self):
        """
        Gets the workflow of this CustomAgentOutputV1.
        Opaque workflow JSON payload as a string

        :return: The workflow of this CustomAgentOutputV1.
        :rtype: str
        """
        return self._workflow

    @workflow.setter
    def workflow(self, workflow):
        """
        Sets the workflow of this CustomAgentOutputV1.
        Opaque workflow JSON payload as a string

        :param workflow: The workflow of this CustomAgentOutputV1.
        :type: str
        """
        if workflow is None:
            raise ValueError("Invalid value for `workflow`, must not be `None`")

        self._workflow = workflow

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, CustomAgentOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
