# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class UserGroupWithIdInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _data_id: Optional[str]
    _datasource_class: Optional[str]
    _datasource_id: Optional[str]
    _description: Optional[str]
    _is_enabled: Optional[bool]
    _mapping: Optional[bool]
    _mappings: Optional[IdentityMappingListV1]
    _name: str
    _remote_group_editable: Optional[bool]
    _remove_permissions: Optional[bool]
    _sync_token: Optional[str]


    def __init__(
        self,
        data_id: Optional[str] = None,
        datasource_class: Optional[str] = None,
        datasource_id: Optional[str] = None,
        description: Optional[str] = None,
        is_enabled: Optional[bool] = True,
        mapping: Optional[bool] = False,
        mappings: Optional[IdentityMappingListV1] = None,
        name: Optional[str] = None,
        remote_group_editable: Optional[bool] = False,
        remove_permissions: Optional[bool] = False,
        sync_token: Optional[str] = None,
    ) -> None: ...

    @property
    def data_id(self) -> Optional[str]: ...

    @data_id.setter
    def data_id(self, data_id: Optional[str]) -> None: ...

    @property
    def datasource_class(self) -> Optional[str]: ...

    @datasource_class.setter
    def datasource_class(self, datasource_class: Optional[str]) -> None: ...

    @property
    def datasource_id(self) -> Optional[str]: ...

    @datasource_id.setter
    def datasource_id(self, datasource_id: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def is_enabled(self) -> Optional[bool]: ...

    @is_enabled.setter
    def is_enabled(self, is_enabled: Optional[bool]) -> None: ...

    @property
    def mapping(self) -> Optional[bool]: ...

    @mapping.setter
    def mapping(self, mapping: Optional[bool]) -> None: ...

    @property
    def mappings(self) -> Optional[IdentityMappingListV1]: ...

    @mappings.setter
    def mappings(self, mappings: Optional[IdentityMappingListV1]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def remote_group_editable(self) -> Optional[bool]: ...

    @remote_group_editable.setter
    def remote_group_editable(self, remote_group_editable: Optional[bool]) -> None: ...

    @property
    def remove_permissions(self) -> Optional[bool]: ...

    @remove_permissions.setter
    def remove_permissions(self, remove_permissions: Optional[bool]) -> None: ...

    @property
    def sync_token(self) -> Optional[str]: ...

    @sync_token.setter
    def sync_token(self, sync_token: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
