# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AnnotationInterestInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _detail_id: Optional[str]
    _interest_id: str
    _search_interval: Optional[TimeInterval]
    _search_interval_end: Optional[int]
    _search_interval_start: Optional[int]


    def __init__(
        self,
        detail_id: Optional[str] = None,
        interest_id: Optional[str] = None,
        search_interval: Optional[TimeInterval] = None,
        search_interval_end: Optional[int] = None,
        search_interval_start: Optional[int] = None,
    ) -> None: ...

    @property
    def detail_id(self) -> Optional[str]: ...

    @detail_id.setter
    def detail_id(self, detail_id: Optional[str]) -> None: ...

    @property
    def interest_id(self) -> str: ...

    @interest_id.setter
    def interest_id(self, interest_id: str) -> None: ...

    @property
    def search_interval(self) -> Optional[TimeInterval]: ...

    @search_interval.setter
    def search_interval(self, search_interval: Optional[TimeInterval]) -> None: ...

    @property
    def search_interval_end(self) -> Optional[int]: ...

    @search_interval_end.setter
    def search_interval_end(self, search_interval_end: Optional[int]) -> None: ...

    @property
    def search_interval_start(self) -> Optional[int]: ...

    @search_interval_start.setter
    def search_interval_start(self, search_interval_start: Optional[int]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
