# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class TableDefinitionsApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def add_columns_to_table_definition(
        self,
        **kwargs: Any,
    ) -> TableComputeOutputV1: ...

    def add_columns_to_table_definition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def add_overrides_to_column(
        self,
        **kwargs: Any,
    ) -> TableComputeOutputV1: ...

    def add_overrides_to_column_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_table_definition(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def archive_table_definition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def cleanup(
        self,
        **kwargs: Any,
    ) -> DatasourceCleanUpOutputV1: ...

    def cleanup_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_table_definition(
        self,
        **kwargs: Any,
    ) -> TableDefinitionOutputV1: ...

    def create_table_definition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_table_definition_from_csv(
        self,
        **kwargs: Any,
    ) -> TableDefinitionOutputV1: ...

    def create_table_definition_from_csv_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_column_from_table_definition(
        self,
        **kwargs: Any,
    ) -> TableDefinitionOutputV1: ...

    def delete_column_from_table_definition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_overrides_from_column(
        self,
        **kwargs: Any,
    ) -> TableComputeOutputV1: ...

    def delete_overrides_from_column_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_table_definition(
        self,
        **kwargs: Any,
    ) -> TableDefinitionOutputV1: ...

    def get_table_definition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_table_definitions(
        self,
        **kwargs: Any,
    ) -> TableDefinitionOutputListV1: ...

    def get_table_definitions_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def import_table_csv(
        self,
        **kwargs: Any,
    ) -> ImportTableCSVOutputV1: ...

    def import_table_csv_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def modify_column_in_table_definition(
        self,
        **kwargs: Any,
    ) -> TableComputeOutputV1: ...

    def modify_column_in_table_definition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def modify_columns_in_table_definition(
        self,
        **kwargs: Any,
    ) -> TableComputeOutputV1: ...

    def modify_columns_in_table_definition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def preview_table_definition(
        self,
        **kwargs: Any,
    ) -> TableDefinitionPreviewOutputV1: ...

    def preview_table_definition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def publish_rows_from_csv(
        self,
        **kwargs: Any,
    ) -> TableDefinitionCSVPublishRowsOutputV1: ...

    def publish_rows_from_csv_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def recompute_column_in_table_definition(
        self,
        **kwargs: Any,
    ) -> TableComputeOutputV1: ...

    def recompute_column_in_table_definition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def reorder_columns_in_table_definition(
        self,
        **kwargs: Any,
    ) -> TableDefinitionOutputV1: ...

    def reorder_columns_in_table_definition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_table_definition(
        self,
        **kwargs: Any,
    ) -> TableDefinitionOutputV1: ...

    def update_table_definition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_table_definition_from_csv(
        self,
        **kwargs: Any,
    ) -> TableDefinitionOutputV1: ...

    def update_table_definition_from_csv_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
