# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class TileUpdateInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _background_color: Optional[str]
    _border_color: Optional[str]
    _chart_options: Optional[str]
    _compare_range_end: Optional[str]
    _compare_range_start: Optional[str]
    _data_view_id: Optional[str]
    _date_range_end: Optional[str]
    _date_range_start: Optional[str]
    _decimal_places: Optional[int]
    _grouped_by_key: Optional[str]
    _height: Optional[int]
    _name: Optional[str]
    _prompt: Optional[str]
    _rehydration_instructions: Optional[RehydrationInstructionsInputV1]
    _tolerance: Optional[float]
    _type: Optional[str]
    _unit: Optional[str]
    _value_column: Optional[str]
    _version: Optional[str]
    _width: Optional[int]
    _worksheet_id: Optional[str]
    _x: Optional[int]
    _y: Optional[int]


    def __init__(
        self,
        background_color: Optional[str] = None,
        border_color: Optional[str] = None,
        chart_options: Optional[str] = None,
        compare_range_end: Optional[str] = None,
        compare_range_start: Optional[str] = None,
        data_view_id: Optional[str] = None,
        date_range_end: Optional[str] = None,
        date_range_start: Optional[str] = None,
        decimal_places: Optional[int] = None,
        grouped_by_key: Optional[str] = None,
        height: Optional[int] = None,
        name: Optional[str] = None,
        prompt: Optional[str] = None,
        rehydration_instructions: Optional[RehydrationInstructionsInputV1] = None,
        tolerance: Optional[float] = None,
        type: Optional[str] = None,
        unit: Optional[str] = None,
        value_column: Optional[str] = None,
        version: Optional[str] = None,
        width: Optional[int] = None,
        worksheet_id: Optional[str] = None,
        x: Optional[int] = None,
        y: Optional[int] = None,
    ) -> None: ...

    @property
    def background_color(self) -> Optional[str]: ...

    @background_color.setter
    def background_color(self, background_color: Optional[str]) -> None: ...

    @property
    def border_color(self) -> Optional[str]: ...

    @border_color.setter
    def border_color(self, border_color: Optional[str]) -> None: ...

    @property
    def chart_options(self) -> Optional[str]: ...

    @chart_options.setter
    def chart_options(self, chart_options: Optional[str]) -> None: ...

    @property
    def compare_range_end(self) -> Optional[str]: ...

    @compare_range_end.setter
    def compare_range_end(self, compare_range_end: Optional[str]) -> None: ...

    @property
    def compare_range_start(self) -> Optional[str]: ...

    @compare_range_start.setter
    def compare_range_start(self, compare_range_start: Optional[str]) -> None: ...

    @property
    def data_view_id(self) -> Optional[str]: ...

    @data_view_id.setter
    def data_view_id(self, data_view_id: Optional[str]) -> None: ...

    @property
    def date_range_end(self) -> Optional[str]: ...

    @date_range_end.setter
    def date_range_end(self, date_range_end: Optional[str]) -> None: ...

    @property
    def date_range_start(self) -> Optional[str]: ...

    @date_range_start.setter
    def date_range_start(self, date_range_start: Optional[str]) -> None: ...

    @property
    def decimal_places(self) -> Optional[int]: ...

    @decimal_places.setter
    def decimal_places(self, decimal_places: Optional[int]) -> None: ...

    @property
    def grouped_by_key(self) -> Optional[str]: ...

    @grouped_by_key.setter
    def grouped_by_key(self, grouped_by_key: Optional[str]) -> None: ...

    @property
    def height(self) -> Optional[int]: ...

    @height.setter
    def height(self, height: Optional[int]) -> None: ...

    @property
    def name(self) -> Optional[str]: ...

    @name.setter
    def name(self, name: Optional[str]) -> None: ...

    @property
    def prompt(self) -> Optional[str]: ...

    @prompt.setter
    def prompt(self, prompt: Optional[str]) -> None: ...

    @property
    def rehydration_instructions(self) -> Optional[RehydrationInstructionsInputV1]: ...

    @rehydration_instructions.setter
    def rehydration_instructions(self, rehydration_instructions: Optional[RehydrationInstructionsInputV1]) -> None: ...

    @property
    def tolerance(self) -> Optional[float]: ...

    @tolerance.setter
    def tolerance(self, tolerance: Optional[float]) -> None: ...

    @property
    def type(self) -> Optional[str]: ...

    @type.setter
    def type(self, type: Optional[str]) -> None: ...

    @property
    def unit(self) -> Optional[str]: ...

    @unit.setter
    def unit(self, unit: Optional[str]) -> None: ...

    @property
    def value_column(self) -> Optional[str]: ...

    @value_column.setter
    def value_column(self, value_column: Optional[str]) -> None: ...

    @property
    def version(self) -> Optional[str]: ...

    @version.setter
    def version(self, version: Optional[str]) -> None: ...

    @property
    def width(self) -> Optional[int]: ...

    @width.setter
    def width(self, width: Optional[int]) -> None: ...

    @property
    def worksheet_id(self) -> Optional[str]: ...

    @worksheet_id.setter
    def worksheet_id(self, worksheet_id: Optional[str]) -> None: ...

    @property
    def x(self) -> Optional[int]: ...

    @x.setter
    def x(self, x: Optional[int]) -> None: ...

    @property
    def y(self) -> Optional[int]: ...

    @y.setter
    def y(self, y: Optional[int]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
