# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class BoardCreateInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'applied_filter': 'str',
        'background_color': 'str',
        'columns': 'int',
        'description': 'str',
        'name': 'str',
        'row_height': 'int',
        'scoped_to': 'str',
        'timezone': 'str'
    }

    attribute_map = {
        'applied_filter': 'appliedFilter',
        'background_color': 'backgroundColor',
        'columns': 'columns',
        'description': 'description',
        'name': 'name',
        'row_height': 'rowHeight',
        'scoped_to': 'scopedTo',
        'timezone': 'timezone'
    }

    def __init__(self, applied_filter=None, background_color=None, columns=None, description=None, name=None, row_height=None, scoped_to=None, timezone=None):
        """
        BoardCreateInputV1 - a model defined in Swagger
        """

        self._applied_filter = None
        self._background_color = None
        self._columns = None
        self._description = None
        self._name = None
        self._row_height = None
        self._scoped_to = None
        self._timezone = None

        if applied_filter is not None:
          self.applied_filter = applied_filter
        if background_color is not None:
          self.background_color = background_color
        if columns is not None:
          self.columns = columns
        if description is not None:
          self.description = description
        if name is not None:
          self.name = name
        if row_height is not None:
          self.row_height = row_height
        if scoped_to is not None:
          self.scoped_to = scoped_to
        if timezone is not None:
          self.timezone = timezone

    @property
    def applied_filter(self):
        """
        Gets the applied_filter of this BoardCreateInputV1.
        The applied filter configuration as JSON

        :return: The applied_filter of this BoardCreateInputV1.
        :rtype: str
        """
        return self._applied_filter

    @applied_filter.setter
    def applied_filter(self, applied_filter):
        """
        Sets the applied_filter of this BoardCreateInputV1.
        The applied filter configuration as JSON

        :param applied_filter: The applied_filter of this BoardCreateInputV1.
        :type: str
        """

        self._applied_filter = applied_filter

    @property
    def background_color(self):
        """
        Gets the background_color of this BoardCreateInputV1.
        The background color of the board (CSS color value)

        :return: The background_color of this BoardCreateInputV1.
        :rtype: str
        """
        return self._background_color

    @background_color.setter
    def background_color(self, background_color):
        """
        Sets the background_color of this BoardCreateInputV1.
        The background color of the board (CSS color value)

        :param background_color: The background_color of this BoardCreateInputV1.
        :type: str
        """

        self._background_color = background_color

    @property
    def columns(self):
        """
        Gets the columns of this BoardCreateInputV1.
        The number of columns in the board grid

        :return: The columns of this BoardCreateInputV1.
        :rtype: int
        """
        return self._columns

    @columns.setter
    def columns(self, columns):
        """
        Sets the columns of this BoardCreateInputV1.
        The number of columns in the board grid

        :param columns: The columns of this BoardCreateInputV1.
        :type: int
        """

        self._columns = columns

    @property
    def description(self):
        """
        Gets the description of this BoardCreateInputV1.
        The description of the board

        :return: The description of this BoardCreateInputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this BoardCreateInputV1.
        The description of the board

        :param description: The description of this BoardCreateInputV1.
        :type: str
        """

        self._description = description

    @property
    def name(self):
        """
        Gets the name of this BoardCreateInputV1.
        The name of the board

        :return: The name of this BoardCreateInputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this BoardCreateInputV1.
        The name of the board

        :param name: The name of this BoardCreateInputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def row_height(self):
        """
        Gets the row_height of this BoardCreateInputV1.
        The height of each row in grid units

        :return: The row_height of this BoardCreateInputV1.
        :rtype: int
        """
        return self._row_height

    @row_height.setter
    def row_height(self, row_height):
        """
        Sets the row_height of this BoardCreateInputV1.
        The height of each row in grid units

        :param row_height: The row_height of this BoardCreateInputV1.
        :type: int
        """

        self._row_height = row_height

    @property
    def scoped_to(self):
        """
        Gets the scoped_to of this BoardCreateInputV1.
        The ID of the workbook to which the board will be scoped

        :return: The scoped_to of this BoardCreateInputV1.
        :rtype: str
        """
        return self._scoped_to

    @scoped_to.setter
    def scoped_to(self, scoped_to):
        """
        Sets the scoped_to of this BoardCreateInputV1.
        The ID of the workbook to which the board will be scoped

        :param scoped_to: The scoped_to of this BoardCreateInputV1.
        :type: str
        """

        self._scoped_to = scoped_to

    @property
    def timezone(self):
        """
        Gets the timezone of this BoardCreateInputV1.
        The timezone for the board (IANA timezone identifier)

        :return: The timezone of this BoardCreateInputV1.
        :rtype: str
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        """
        Sets the timezone of this BoardCreateInputV1.
        The timezone for the board (IANA timezone identifier)

        :param timezone: The timezone of this BoardCreateInputV1.
        :type: str
        """
        if timezone is None:
            raise ValueError("Invalid value for `timezone`, must not be `None`")

        self._timezone = timezone

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, BoardCreateInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
