# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ItemSearchInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _asset: Optional[str]
    _filters: Optional[List[str]]
    _include_properties: Optional[List[str]]
    _limit: Optional[int]
    _offset: Optional[int]
    _order_by_fields: Optional[List[str]]
    _scope: Optional[List[str]]
    _types: Optional[List[str]]


    def __init__(
        self,
        asset: Optional[str] = None,
        filters: Optional[List[str]] = None,
        include_properties: Optional[List[str]] = None,
        limit: Optional[int] = 40,
        offset: Optional[int] = 0,
        order_by_fields: Optional[List[str]] = None,
        scope: Optional[List[str]] = None,
        types: Optional[List[str]] = None,
    ) -> None: ...

    @property
    def asset(self) -> Optional[str]: ...

    @asset.setter
    def asset(self, asset: Optional[str]) -> None: ...

    @property
    def filters(self) -> Optional[List[str]]: ...

    @filters.setter
    def filters(self, filters: Optional[List[str]]) -> None: ...

    @property
    def include_properties(self) -> Optional[List[str]]: ...

    @include_properties.setter
    def include_properties(self, include_properties: Optional[List[str]]) -> None: ...

    @property
    def limit(self) -> Optional[int]: ...

    @limit.setter
    def limit(self, limit: Optional[int]) -> None: ...

    @property
    def offset(self) -> Optional[int]: ...

    @offset.setter
    def offset(self, offset: Optional[int]) -> None: ...

    @property
    def order_by_fields(self) -> Optional[List[str]]: ...

    @order_by_fields.setter
    def order_by_fields(self, order_by_fields: Optional[List[str]]) -> None: ...

    @property
    def scope(self) -> Optional[List[str]]: ...

    @scope.setter
    def scope(self, scope: Optional[List[str]]) -> None: ...

    @property
    def types(self) -> Optional[List[str]]: ...

    @types.setter
    def types(self, types: Optional[List[str]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
