# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AssetGroupAssetInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _additional_properties: Optional[List[ScalarPropertyV1]]
    _children: Optional[List[FormulaItemInputV1]]
    _data_id: Optional[str]
    _description: Optional[str]
    _host_id: Optional[str]
    _id: Optional[str]
    _manually_added: Optional[str]
    _name: str
    _properties: Optional[List[ScalarPropertyV1]]
    _scoped_to: Optional[str]
    _security_string: Optional[str]
    _source_security_string: Optional[str]
    _sync_token: Optional[str]


    def __init__(
        self,
        additional_properties: Optional[List[ScalarPropertyV1]] = None,
        children: Optional[List[FormulaItemInputV1]] = None,
        data_id: Optional[str] = None,
        description: Optional[str] = None,
        host_id: Optional[str] = None,
        id: Optional[str] = None,
        manually_added: Optional[str] = None,
        name: Optional[str] = None,
        properties: Optional[List[ScalarPropertyV1]] = None,
        scoped_to: Optional[str] = None,
        security_string: Optional[str] = None,
        source_security_string: Optional[str] = None,
        sync_token: Optional[str] = None,
    ) -> None: ...

    @property
    def additional_properties(self) -> Optional[List[ScalarPropertyV1]]: ...

    @additional_properties.setter
    def additional_properties(self, additional_properties: Optional[List[ScalarPropertyV1]]) -> None: ...

    @property
    def children(self) -> Optional[List[FormulaItemInputV1]]: ...

    @children.setter
    def children(self, children: Optional[List[FormulaItemInputV1]]) -> None: ...

    @property
    def data_id(self) -> Optional[str]: ...

    @data_id.setter
    def data_id(self, data_id: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def host_id(self) -> Optional[str]: ...

    @host_id.setter
    def host_id(self, host_id: Optional[str]) -> None: ...

    @property
    def id(self) -> Optional[str]: ...

    @id.setter
    def id(self, id: Optional[str]) -> None: ...

    @property
    def manually_added(self) -> Optional[str]: ...

    @manually_added.setter
    def manually_added(self, manually_added: Optional[str]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def properties(self) -> Optional[List[ScalarPropertyV1]]: ...

    @properties.setter
    def properties(self, properties: Optional[List[ScalarPropertyV1]]) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def security_string(self) -> Optional[str]: ...

    @security_string.setter
    def security_string(self, security_string: Optional[str]) -> None: ...

    @property
    def source_security_string(self) -> Optional[str]: ...

    @source_security_string.setter
    def source_security_string(self, source_security_string: Optional[str]) -> None: ...

    @property
    def sync_token(self) -> Optional[str]: ...

    @sync_token.setter
    def sync_token(self, sync_token: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
