# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class BoardTimeframeComparisonTileOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _skip_reason: Optional[str]
    _skipped: bool
    _tile_id: str
    _tile_name: str
    _tile_type: str
    _variations: List[BoardTimeframeComparisonMetricOutputV1]


    def __init__(
        self,
        skip_reason: Optional[str] = None,
        skipped: Optional[bool] = None,
        tile_id: Optional[str] = None,
        tile_name: Optional[str] = None,
        tile_type: Optional[str] = None,
        variations: Optional[List[BoardTimeframeComparisonMetricOutputV1]] = None,
    ) -> None: ...

    @property
    def skip_reason(self) -> Optional[str]: ...

    @skip_reason.setter
    def skip_reason(self, skip_reason: Optional[str]) -> None: ...

    @property
    def skipped(self) -> bool: ...

    @skipped.setter
    def skipped(self, skipped: bool) -> None: ...

    @property
    def tile_id(self) -> str: ...

    @tile_id.setter
    def tile_id(self, tile_id: str) -> None: ...

    @property
    def tile_name(self) -> str: ...

    @tile_name.setter
    def tile_name(self, tile_name: str) -> None: ...

    @property
    def tile_type(self) -> str: ...

    @tile_type.setter
    def tile_type(self, tile_type: str) -> None: ...

    @property
    def variations(self) -> List[BoardTimeframeComparisonMetricOutputV1]: ...

    @variations.setter
    def variations(self, variations: List[BoardTimeframeComparisonMetricOutputV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
