# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class FolderOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _ancestors: Optional[List[ItemPreviewV1]]
    _created_at: Optional[str]
    _creator: Optional[IdentityPreviewV1]
    _description: Optional[str]
    _effective_permissions: Optional[PermissionsV1]
    _id: str
    _is_archived: Optional[bool]
    _is_organization_folder: Optional[bool]
    _is_redacted: Optional[bool]
    _marked_as_favorite: Optional[bool]
    _name: str
    _organization_folder: Optional[bool]
    _owner: Optional[IdentityPreviewV1]
    _parent_folder_id: Optional[str]
    _status_message: Optional[str]
    _translation_key: Optional[str]
    _type: str
    _updated_at: Optional[str]


    def __init__(
        self,
        ancestors: Optional[List[ItemPreviewV1]] = None,
        created_at: Optional[str] = None,
        creator: Optional[IdentityPreviewV1] = None,
        description: Optional[str] = None,
        effective_permissions: Optional[PermissionsV1] = None,
        id: Optional[str] = None,
        is_archived: Optional[bool] = False,
        is_organization_folder: Optional[bool] = False,
        is_redacted: Optional[bool] = False,
        marked_as_favorite: Optional[bool] = False,
        name: Optional[str] = None,
        organization_folder: Optional[bool] = None,
        owner: Optional[IdentityPreviewV1] = None,
        parent_folder_id: Optional[str] = None,
        status_message: Optional[str] = None,
        translation_key: Optional[str] = None,
        type: Optional[str] = None,
        updated_at: Optional[str] = None,
    ) -> None: ...

    @property
    def ancestors(self) -> Optional[List[ItemPreviewV1]]: ...

    @ancestors.setter
    def ancestors(self, ancestors: Optional[List[ItemPreviewV1]]) -> None: ...

    @property
    def created_at(self) -> Optional[str]: ...

    @created_at.setter
    def created_at(self, created_at: Optional[str]) -> None: ...

    @property
    def creator(self) -> Optional[IdentityPreviewV1]: ...

    @creator.setter
    def creator(self, creator: Optional[IdentityPreviewV1]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def effective_permissions(self) -> Optional[PermissionsV1]: ...

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions: Optional[PermissionsV1]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def is_organization_folder(self) -> Optional[bool]: ...

    @is_organization_folder.setter
    def is_organization_folder(self, is_organization_folder: Optional[bool]) -> None: ...

    @property
    def is_redacted(self) -> Optional[bool]: ...

    @is_redacted.setter
    def is_redacted(self, is_redacted: Optional[bool]) -> None: ...

    @property
    def marked_as_favorite(self) -> Optional[bool]: ...

    @marked_as_favorite.setter
    def marked_as_favorite(self, marked_as_favorite: Optional[bool]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def organization_folder(self) -> Optional[bool]: ...

    @organization_folder.setter
    def organization_folder(self, organization_folder: Optional[bool]) -> None: ...

    @property
    def owner(self) -> Optional[IdentityPreviewV1]: ...

    @owner.setter
    def owner(self, owner: Optional[IdentityPreviewV1]) -> None: ...

    @property
    def parent_folder_id(self) -> Optional[str]: ...

    @parent_folder_id.setter
    def parent_folder_id(self, parent_folder_id: Optional[str]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def translation_key(self) -> Optional[str]: ...

    @translation_key.setter
    def translation_key(self, translation_key: Optional[str]) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    @property
    def updated_at(self) -> Optional[str]: ...

    @updated_at.setter
    def updated_at(self, updated_at: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
