# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class LabelHierarchyInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'depth': 'int',
        'include_archived': 'bool',
        'max_nodes': 'int',
        'pairs': 'list[CategoryLabelPairInputV1]'
    }

    attribute_map = {
        'depth': 'depth',
        'include_archived': 'includeArchived',
        'max_nodes': 'maxNodes',
        'pairs': 'pairs'
    }

    def __init__(self, depth=10, include_archived=False, max_nodes=1000, pairs=None):
        """
        LabelHierarchyInputV1 - a model defined in Swagger
        """

        self._depth = None
        self._include_archived = None
        self._max_nodes = None
        self._pairs = None

        if depth is not None:
          self.depth = depth
        if include_archived is not None:
          self.include_archived = include_archived
        if max_nodes is not None:
          self.max_nodes = max_nodes
        if pairs is not None:
          self.pairs = pairs

    @property
    def depth(self):
        """
        Gets the depth of this LabelHierarchyInputV1.
        Maximum depth to traverse in the hierarchy. Must be between 1 and 50. Default is 10.

        :return: The depth of this LabelHierarchyInputV1.
        :rtype: int
        """
        return self._depth

    @depth.setter
    def depth(self, depth):
        """
        Sets the depth of this LabelHierarchyInputV1.
        Maximum depth to traverse in the hierarchy. Must be between 1 and 50. Default is 10.

        :param depth: The depth of this LabelHierarchyInputV1.
        :type: int
        """

        self._depth = depth

    @property
    def include_archived(self):
        """
        Gets the include_archived of this LabelHierarchyInputV1.
        If true, include archived labels and categories in the results. Default is false.

        :return: The include_archived of this LabelHierarchyInputV1.
        :rtype: bool
        """
        return self._include_archived

    @include_archived.setter
    def include_archived(self, include_archived):
        """
        Sets the include_archived of this LabelHierarchyInputV1.
        If true, include archived labels and categories in the results. Default is false.

        :param include_archived: The include_archived of this LabelHierarchyInputV1.
        :type: bool
        """

        self._include_archived = include_archived

    @property
    def max_nodes(self):
        """
        Gets the max_nodes of this LabelHierarchyInputV1.
        Maximum total nodes returned across all roots. Must be between 1 and 10000. Default is 1000.

        :return: The max_nodes of this LabelHierarchyInputV1.
        :rtype: int
        """
        return self._max_nodes

    @max_nodes.setter
    def max_nodes(self, max_nodes):
        """
        Sets the max_nodes of this LabelHierarchyInputV1.
        Maximum total nodes returned across all roots. Must be between 1 and 10000. Default is 1000.

        :param max_nodes: The max_nodes of this LabelHierarchyInputV1.
        :type: int
        """

        self._max_nodes = max_nodes

    @property
    def pairs(self):
        """
        Gets the pairs of this LabelHierarchyInputV1.
        List of category/label pairs to use as root nodes for the hierarchies

        :return: The pairs of this LabelHierarchyInputV1.
        :rtype: list[CategoryLabelPairInputV1]
        """
        return self._pairs

    @pairs.setter
    def pairs(self, pairs):
        """
        Sets the pairs of this LabelHierarchyInputV1.
        List of category/label pairs to use as root nodes for the hierarchies

        :param pairs: The pairs of this LabelHierarchyInputV1.
        :type: list[CategoryLabelPairInputV1]
        """

        self._pairs = pairs

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, LabelHierarchyInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
