# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ConnectionInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _backup_name: Optional[str]
    _datasource_id: Optional[str]
    _enabled: Optional[bool]
    _json: Optional[str]
    _max_concurrent_requests: Optional[int]
    _max_results_per_requests: Optional[int]
    _transforms: Optional[str]


    def __init__(
        self,
        backup_name: Optional[str] = None,
        datasource_id: Optional[str] = None,
        enabled: Optional[bool] = True,
        json: Optional[str] = None,
        max_concurrent_requests: Optional[int] = None,
        max_results_per_requests: Optional[int] = None,
        transforms: Optional[str] = None,
    ) -> None: ...

    @property
    def backup_name(self) -> Optional[str]: ...

    @backup_name.setter
    def backup_name(self, backup_name: Optional[str]) -> None: ...

    @property
    def datasource_id(self) -> Optional[str]: ...

    @datasource_id.setter
    def datasource_id(self, datasource_id: Optional[str]) -> None: ...

    @property
    def enabled(self) -> Optional[bool]: ...

    @enabled.setter
    def enabled(self, enabled: Optional[bool]) -> None: ...

    @property
    def json(self) -> Optional[str]: ...

    @json.setter
    def json(self, json: Optional[str]) -> None: ...

    @property
    def max_concurrent_requests(self) -> Optional[int]: ...

    @max_concurrent_requests.setter
    def max_concurrent_requests(self, max_concurrent_requests: Optional[int]) -> None: ...

    @property
    def max_results_per_requests(self) -> Optional[int]: ...

    @max_results_per_requests.setter
    def max_results_per_requests(self, max_results_per_requests: Optional[int]) -> None: ...

    @property
    def transforms(self) -> Optional[str]: ...

    @transforms.setter
    def transforms(self, transforms: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
