# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ListConfigFieldV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _element_config_field: Optional[ConfigFieldV1]
    _element_type: Optional[str]
    _max_item_count: Optional[int]
    _min_item_count: Optional[int]


    def __init__(
        self,
        element_config_field: Optional[ConfigFieldV1] = None,
        element_type: Optional[str] = None,
        max_item_count: Optional[int] = None,
        min_item_count: Optional[int] = None,
    ) -> None: ...

    @property
    def element_config_field(self) -> Optional[ConfigFieldV1]: ...

    @element_config_field.setter
    def element_config_field(self, element_config_field: Optional[ConfigFieldV1]) -> None: ...

    @property
    def element_type(self) -> Optional[str]: ...

    @element_type.setter
    def element_type(self, element_type: Optional[str]) -> None: ...

    @property
    def max_item_count(self) -> Optional[int]: ...

    @max_item_count.setter
    def max_item_count(self, max_item_count: Optional[int]) -> None: ...

    @property
    def min_item_count(self) -> Optional[int]: ...

    @min_item_count.setter
    def min_item_count(self, min_item_count: Optional[int]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
