# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class MonitorValues(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _count: Optional[int]
    _fifteen_minute_rate: Optional[float]
    _five_minute_rate: Optional[float]
    _max: Optional[float]
    _mean: Optional[float]
    _min: Optional[float]
    _one_minute_rate: Optional[float]
    _p50: Optional[float]
    _p75: Optional[float]
    _p95: Optional[float]
    _p98: Optional[float]
    _p99: Optional[float]
    _p999: Optional[float]
    _stddev: Optional[float]
    _string_value: Optional[str]
    _value: Optional[float]


    def __init__(
        self,
        count: Optional[int] = None,
        fifteen_minute_rate: Optional[float] = None,
        five_minute_rate: Optional[float] = None,
        max: Optional[float] = None,
        mean: Optional[float] = None,
        min: Optional[float] = None,
        one_minute_rate: Optional[float] = None,
        p50: Optional[float] = None,
        p75: Optional[float] = None,
        p95: Optional[float] = None,
        p98: Optional[float] = None,
        p99: Optional[float] = None,
        p999: Optional[float] = None,
        stddev: Optional[float] = None,
        string_value: Optional[str] = None,
        value: Optional[float] = None,
    ) -> None: ...

    @property
    def count(self) -> Optional[int]: ...

    @count.setter
    def count(self, count: Optional[int]) -> None: ...

    @property
    def fifteen_minute_rate(self) -> Optional[float]: ...

    @fifteen_minute_rate.setter
    def fifteen_minute_rate(self, fifteen_minute_rate: Optional[float]) -> None: ...

    @property
    def five_minute_rate(self) -> Optional[float]: ...

    @five_minute_rate.setter
    def five_minute_rate(self, five_minute_rate: Optional[float]) -> None: ...

    @property
    def max(self) -> Optional[float]: ...

    @max.setter
    def max(self, max: Optional[float]) -> None: ...

    @property
    def mean(self) -> Optional[float]: ...

    @mean.setter
    def mean(self, mean: Optional[float]) -> None: ...

    @property
    def min(self) -> Optional[float]: ...

    @min.setter
    def min(self, min: Optional[float]) -> None: ...

    @property
    def one_minute_rate(self) -> Optional[float]: ...

    @one_minute_rate.setter
    def one_minute_rate(self, one_minute_rate: Optional[float]) -> None: ...

    @property
    def p50(self) -> Optional[float]: ...

    @p50.setter
    def p50(self, p50: Optional[float]) -> None: ...

    @property
    def p75(self) -> Optional[float]: ...

    @p75.setter
    def p75(self, p75: Optional[float]) -> None: ...

    @property
    def p95(self) -> Optional[float]: ...

    @p95.setter
    def p95(self, p95: Optional[float]) -> None: ...

    @property
    def p98(self) -> Optional[float]: ...

    @p98.setter
    def p98(self, p98: Optional[float]) -> None: ...

    @property
    def p99(self) -> Optional[float]: ...

    @p99.setter
    def p99(self, p99: Optional[float]) -> None: ...

    @property
    def p999(self) -> Optional[float]: ...

    @p999.setter
    def p999(self, p999: Optional[float]) -> None: ...

    @property
    def stddev(self) -> Optional[float]: ...

    @stddev.setter
    def stddev(self, stddev: Optional[float]) -> None: ...

    @property
    def string_value(self) -> Optional[str]: ...

    @string_value.setter
    def string_value(self, string_value: Optional[str]) -> None: ...

    @property
    def value(self) -> Optional[float]: ...

    @value.setter
    def value(self, value: Optional[float]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
