# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class DatafileInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _additional_properties: Optional[List[ScalarPropertyV1]]
    _append: Optional[bool]
    _condition_name: Optional[str]
    _data_id: Optional[str]
    _day_first_default: Optional[bool]
    _description: Optional[str]
    _description_row: Optional[int]
    _end_column_index: Optional[int]
    _end_column_name: Optional[str]
    _field_delimiter: Optional[str]
    _filename: Optional[str]
    _first_data_row: Optional[int]
    _host_id: Optional[str]
    _interpolation_method: Optional[str]
    _interpolation_method_row: Optional[int]
    _item_type: Optional[str]
    _key_column_index: Optional[int]
    _key_column_name: Optional[str]
    _key_format: Optional[str]
    _lenient_daylight_savings: Optional[bool]
    _maximum_duration: Optional[str]
    _maximum_interpolation: Optional[str]
    _maximum_interpolation_row: Optional[int]
    _name: str
    _name_prefix: Optional[str]
    _name_row: Optional[int]
    _name_suffix: Optional[str]
    _properties: Optional[List[ScalarPropertyV1]]
    _scoped_to: Optional[str]
    _time_zone: Optional[str]
    _upload_filename: str
    _validation_mode: Optional[str]
    _value_column_indices: Optional[str]
    _value_column_names: Optional[str]
    _value_uom: Optional[str]
    _value_uom_row: Optional[int]


    def __init__(
        self,
        additional_properties: Optional[List[ScalarPropertyV1]] = None,
        append: Optional[bool] = False,
        condition_name: Optional[str] = None,
        data_id: Optional[str] = None,
        day_first_default: Optional[bool] = False,
        description: Optional[str] = None,
        description_row: Optional[int] = None,
        end_column_index: Optional[int] = None,
        end_column_name: Optional[str] = None,
        field_delimiter: Optional[str] = None,
        filename: Optional[str] = None,
        first_data_row: Optional[int] = None,
        host_id: Optional[str] = None,
        interpolation_method: Optional[str] = None,
        interpolation_method_row: Optional[int] = None,
        item_type: Optional[str] = None,
        key_column_index: Optional[int] = None,
        key_column_name: Optional[str] = None,
        key_format: Optional[str] = None,
        lenient_daylight_savings: Optional[bool] = False,
        maximum_duration: Optional[str] = None,
        maximum_interpolation: Optional[str] = None,
        maximum_interpolation_row: Optional[int] = None,
        name: Optional[str] = None,
        name_prefix: Optional[str] = None,
        name_row: Optional[int] = None,
        name_suffix: Optional[str] = None,
        properties: Optional[List[ScalarPropertyV1]] = None,
        scoped_to: Optional[str] = None,
        time_zone: Optional[str] = None,
        upload_filename: Optional[str] = None,
        validation_mode: Optional[str] = None,
        value_column_indices: Optional[str] = None,
        value_column_names: Optional[str] = None,
        value_uom: Optional[str] = None,
        value_uom_row: Optional[int] = None,
    ) -> None: ...

    @property
    def additional_properties(self) -> Optional[List[ScalarPropertyV1]]: ...

    @additional_properties.setter
    def additional_properties(self, additional_properties: Optional[List[ScalarPropertyV1]]) -> None: ...

    @property
    def append(self) -> Optional[bool]: ...

    @append.setter
    def append(self, append: Optional[bool]) -> None: ...

    @property
    def condition_name(self) -> Optional[str]: ...

    @condition_name.setter
    def condition_name(self, condition_name: Optional[str]) -> None: ...

    @property
    def data_id(self) -> Optional[str]: ...

    @data_id.setter
    def data_id(self, data_id: Optional[str]) -> None: ...

    @property
    def day_first_default(self) -> Optional[bool]: ...

    @day_first_default.setter
    def day_first_default(self, day_first_default: Optional[bool]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def description_row(self) -> Optional[int]: ...

    @description_row.setter
    def description_row(self, description_row: Optional[int]) -> None: ...

    @property
    def end_column_index(self) -> Optional[int]: ...

    @end_column_index.setter
    def end_column_index(self, end_column_index: Optional[int]) -> None: ...

    @property
    def end_column_name(self) -> Optional[str]: ...

    @end_column_name.setter
    def end_column_name(self, end_column_name: Optional[str]) -> None: ...

    @property
    def field_delimiter(self) -> Optional[str]: ...

    @field_delimiter.setter
    def field_delimiter(self, field_delimiter: Optional[str]) -> None: ...

    @property
    def filename(self) -> Optional[str]: ...

    @filename.setter
    def filename(self, filename: Optional[str]) -> None: ...

    @property
    def first_data_row(self) -> Optional[int]: ...

    @first_data_row.setter
    def first_data_row(self, first_data_row: Optional[int]) -> None: ...

    @property
    def host_id(self) -> Optional[str]: ...

    @host_id.setter
    def host_id(self, host_id: Optional[str]) -> None: ...

    @property
    def interpolation_method(self) -> Optional[str]: ...

    @interpolation_method.setter
    def interpolation_method(self, interpolation_method: Optional[str]) -> None: ...

    @property
    def interpolation_method_row(self) -> Optional[int]: ...

    @interpolation_method_row.setter
    def interpolation_method_row(self, interpolation_method_row: Optional[int]) -> None: ...

    @property
    def item_type(self) -> Optional[str]: ...

    @item_type.setter
    def item_type(self, item_type: Optional[str]) -> None: ...

    @property
    def key_column_index(self) -> Optional[int]: ...

    @key_column_index.setter
    def key_column_index(self, key_column_index: Optional[int]) -> None: ...

    @property
    def key_column_name(self) -> Optional[str]: ...

    @key_column_name.setter
    def key_column_name(self, key_column_name: Optional[str]) -> None: ...

    @property
    def key_format(self) -> Optional[str]: ...

    @key_format.setter
    def key_format(self, key_format: Optional[str]) -> None: ...

    @property
    def lenient_daylight_savings(self) -> Optional[bool]: ...

    @lenient_daylight_savings.setter
    def lenient_daylight_savings(self, lenient_daylight_savings: Optional[bool]) -> None: ...

    @property
    def maximum_duration(self) -> Optional[str]: ...

    @maximum_duration.setter
    def maximum_duration(self, maximum_duration: Optional[str]) -> None: ...

    @property
    def maximum_interpolation(self) -> Optional[str]: ...

    @maximum_interpolation.setter
    def maximum_interpolation(self, maximum_interpolation: Optional[str]) -> None: ...

    @property
    def maximum_interpolation_row(self) -> Optional[int]: ...

    @maximum_interpolation_row.setter
    def maximum_interpolation_row(self, maximum_interpolation_row: Optional[int]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def name_prefix(self) -> Optional[str]: ...

    @name_prefix.setter
    def name_prefix(self, name_prefix: Optional[str]) -> None: ...

    @property
    def name_row(self) -> Optional[int]: ...

    @name_row.setter
    def name_row(self, name_row: Optional[int]) -> None: ...

    @property
    def name_suffix(self) -> Optional[str]: ...

    @name_suffix.setter
    def name_suffix(self, name_suffix: Optional[str]) -> None: ...

    @property
    def properties(self) -> Optional[List[ScalarPropertyV1]]: ...

    @properties.setter
    def properties(self, properties: Optional[List[ScalarPropertyV1]]) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def time_zone(self) -> Optional[str]: ...

    @time_zone.setter
    def time_zone(self, time_zone: Optional[str]) -> None: ...

    @property
    def upload_filename(self) -> str: ...

    @upload_filename.setter
    def upload_filename(self, upload_filename: str) -> None: ...

    @property
    def validation_mode(self) -> Optional[str]: ...

    @validation_mode.setter
    def validation_mode(self, validation_mode: Optional[str]) -> None: ...

    @property
    def value_column_indices(self) -> Optional[str]: ...

    @value_column_indices.setter
    def value_column_indices(self, value_column_indices: Optional[str]) -> None: ...

    @property
    def value_column_names(self) -> Optional[str]: ...

    @value_column_names.setter
    def value_column_names(self, value_column_names: Optional[str]) -> None: ...

    @property
    def value_uom(self) -> Optional[str]: ...

    @value_uom.setter
    def value_uom(self, value_uom: Optional[str]) -> None: ...

    @property
    def value_uom_row(self) -> Optional[int]: ...

    @value_uom_row.setter
    def value_uom_row(self, value_uom_row: Optional[int]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
