# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class VersionOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _created_at: Optional[str]
    _creator: ItemPreviewV1
    _notes: str
    _version: int
    _version_source: Optional[VersionSourceOutputV1]
    _version_source_item: Optional[VersionSourceItemOutputV1]
    _versioned_item: ItemPreviewV1


    def __init__(
        self,
        created_at: Optional[str] = None,
        creator: Optional[ItemPreviewV1] = None,
        notes: Optional[str] = None,
        version: Optional[int] = None,
        version_source: Optional[VersionSourceOutputV1] = None,
        version_source_item: Optional[VersionSourceItemOutputV1] = None,
        versioned_item: Optional[ItemPreviewV1] = None,
    ) -> None: ...

    @property
    def created_at(self) -> Optional[str]: ...

    @created_at.setter
    def created_at(self, created_at: Optional[str]) -> None: ...

    @property
    def creator(self) -> ItemPreviewV1: ...

    @creator.setter
    def creator(self, creator: ItemPreviewV1) -> None: ...

    @property
    def notes(self) -> str: ...

    @notes.setter
    def notes(self, notes: str) -> None: ...

    @property
    def version(self) -> int: ...

    @version.setter
    def version(self, version: int) -> None: ...

    @property
    def version_source(self) -> Optional[VersionSourceOutputV1]: ...

    @version_source.setter
    def version_source(self, version_source: Optional[VersionSourceOutputV1]) -> None: ...

    @property
    def version_source_item(self) -> Optional[VersionSourceItemOutputV1]: ...

    @version_source_item.setter
    def version_source_item(self, version_source_item: Optional[VersionSourceItemOutputV1]) -> None: ...

    @property
    def versioned_item(self) -> ItemPreviewV1: ...

    @versioned_item.setter
    def versioned_item(self, versioned_item: ItemPreviewV1) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
