# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class StoredTablesApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def create_stored_table_from_csv(
        self,
        **kwargs: Any,
    ) -> StoredTableOutputV1: ...

    def create_stored_table_from_csv_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_column_from_stored_table(
        self,
        **kwargs: Any,
    ) -> StoredTableOutputV1: ...

    def delete_column_from_stored_table_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_stored_table_rows(
        self,
        **kwargs: Any,
    ) -> DeleteRowsOutputV1: ...

    def delete_stored_table_rows_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_stored_table(
        self,
        **kwargs: Any,
    ) -> StoredTableOutputV1: ...

    def get_stored_table_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def import_stored_table_csv(
        self,
        **kwargs: Any,
    ) -> ImportTableCSVOutputV1: ...

    def import_stored_table_csv_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def modify_column_in_stored_table(
        self,
        **kwargs: Any,
    ) -> StoredTableOutputV1: ...

    def modify_column_in_stored_table_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_column_data(
        self,
        **kwargs: Any,
    ) -> UpdatedRowsOutputV1: ...

    def update_column_data_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_stored_table_from_csv(
        self,
        **kwargs: Any,
    ) -> StoredTableOutputV1: ...

    def update_stored_table_from_csv_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
