# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ModelTableApplicationsOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'mappings': 'list[ModelApplicationMappingV1]',
        'model_container_id': 'str',
        'model_guid': 'str',
        'model_name': 'str',
        'updated_at': 'str'
    }

    attribute_map = {
        'id': 'id',
        'mappings': 'mappings',
        'model_container_id': 'modelContainerId',
        'model_guid': 'modelGuid',
        'model_name': 'modelName',
        'updated_at': 'updatedAt'
    }

    def __init__(self, id=None, mappings=None, model_container_id=None, model_guid=None, model_name=None, updated_at=None):
        """
        ModelTableApplicationsOutputV1 - a model defined in Swagger
        """

        self._id = None
        self._mappings = None
        self._model_container_id = None
        self._model_guid = None
        self._model_name = None
        self._updated_at = None

        if id is not None:
          self.id = id
        if mappings is not None:
          self.mappings = mappings
        if model_container_id is not None:
          self.model_container_id = model_container_id
        if model_guid is not None:
          self.model_guid = model_guid
        if model_name is not None:
          self.model_name = model_name
        if updated_at is not None:
          self.updated_at = updated_at

    @property
    def id(self):
        """
        Gets the id of this ModelTableApplicationsOutputV1.
        Model Application ID

        :return: The id of this ModelTableApplicationsOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ModelTableApplicationsOutputV1.
        Model Application ID

        :param id: The id of this ModelTableApplicationsOutputV1.
        :type: str
        """

        self._id = id

    @property
    def mappings(self):
        """
        Gets the mappings of this ModelTableApplicationsOutputV1.
        Mapping of column definition IDs or literals to a feature ID

        :return: The mappings of this ModelTableApplicationsOutputV1.
        :rtype: list[ModelApplicationMappingV1]
        """
        return self._mappings

    @mappings.setter
    def mappings(self, mappings):
        """
        Sets the mappings of this ModelTableApplicationsOutputV1.
        Mapping of column definition IDs or literals to a feature ID

        :param mappings: The mappings of this ModelTableApplicationsOutputV1.
        :type: list[ModelApplicationMappingV1]
        """

        self._mappings = mappings

    @property
    def model_container_id(self):
        """
        Gets the model_container_id of this ModelTableApplicationsOutputV1.
        ID of the ModelContainer that is the canonical identity for the model

        :return: The model_container_id of this ModelTableApplicationsOutputV1.
        :rtype: str
        """
        return self._model_container_id

    @model_container_id.setter
    def model_container_id(self, model_container_id):
        """
        Sets the model_container_id of this ModelTableApplicationsOutputV1.
        ID of the ModelContainer that is the canonical identity for the model

        :param model_container_id: The model_container_id of this ModelTableApplicationsOutputV1.
        :type: str
        """

        self._model_container_id = model_container_id

    @property
    def model_guid(self):
        """
        Gets the model_guid of this ModelTableApplicationsOutputV1.
        Model GUID

        :return: The model_guid of this ModelTableApplicationsOutputV1.
        :rtype: str
        """
        return self._model_guid

    @model_guid.setter
    def model_guid(self, model_guid):
        """
        Sets the model_guid of this ModelTableApplicationsOutputV1.
        Model GUID

        :param model_guid: The model_guid of this ModelTableApplicationsOutputV1.
        :type: str
        """

        self._model_guid = model_guid

    @property
    def model_name(self):
        """
        Gets the model_name of this ModelTableApplicationsOutputV1.
        Model Name

        :return: The model_name of this ModelTableApplicationsOutputV1.
        :rtype: str
        """
        return self._model_name

    @model_name.setter
    def model_name(self, model_name):
        """
        Sets the model_name of this ModelTableApplicationsOutputV1.
        Model Name

        :param model_name: The model_name of this ModelTableApplicationsOutputV1.
        :type: str
        """

        self._model_name = model_name

    @property
    def updated_at(self):
        """
        Gets the updated_at of this ModelTableApplicationsOutputV1.
        The UTC timestamp when the model table application was last updated

        :return: The updated_at of this ModelTableApplicationsOutputV1.
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """
        Sets the updated_at of this ModelTableApplicationsOutputV1.
        The UTC timestamp when the model table application was last updated

        :param updated_at: The updated_at of this ModelTableApplicationsOutputV1.
        :type: str
        """

        self._updated_at = updated_at

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ModelTableApplicationsOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
