# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class AnnotationsApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def archive_annotation(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def archive_annotation_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def cors_image_proxy(
        self,
        **kwargs: Any,
    ) -> bytes: ...

    def cors_image_proxy_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_annotation(
        self,
        **kwargs: Any,
    ) -> AnnotationOutputV1: ...

    def create_annotation_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_image(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_image_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_annotation(
        self,
        **kwargs: Any,
    ) -> AnnotationOutputV1: ...

    def get_annotation_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_annotations(
        self,
        **kwargs: Any,
    ) -> AnnotationListOutputV1: ...

    def get_annotations_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_image(
        self,
        **kwargs: Any,
    ) -> bytes: ...

    def get_image_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def migrate_annotation_to_ck_editor(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def migrate_annotation_to_ck_editor_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def publish_report(
        self,
        **kwargs: Any,
    ) -> AnnotationOutputV1: ...

    def publish_report_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_annotation(
        self,
        **kwargs: Any,
    ) -> AnnotationOutputV1: ...

    def update_annotation_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def upload_image(
        self,
        **kwargs: Any,
    ) -> AnnotationImageLinkOutputV1: ...

    def upload_image_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
