# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ModelApplicationErrorOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'feature_id': 'str',
        'message': 'str',
        'message_arguments': 'dict(str, str)',
        'message_number': 'int',
        'model_id': 'str',
        'rule_id': 'str'
    }

    attribute_map = {
        'feature_id': 'featureId',
        'message': 'message',
        'message_arguments': 'messageArguments',
        'message_number': 'messageNumber',
        'model_id': 'modelId',
        'rule_id': 'ruleId'
    }

    def __init__(self, feature_id=None, message=None, message_arguments=None, message_number=None, model_id=None, rule_id=None):
        """
        ModelApplicationErrorOutputV1 - a model defined in Swagger
        """

        self._feature_id = None
        self._message = None
        self._message_arguments = None
        self._message_number = None
        self._model_id = None
        self._rule_id = None

        if feature_id is not None:
          self.feature_id = feature_id
        if message is not None:
          self.message = message
        if message_arguments is not None:
          self.message_arguments = message_arguments
        if message_number is not None:
          self.message_number = message_number
        if model_id is not None:
          self.model_id = model_id
        if rule_id is not None:
          self.rule_id = rule_id

    @property
    def feature_id(self):
        """
        Gets the feature_id of this ModelApplicationErrorOutputV1.
        UUID of the feature being evaluated when the error occurred.

        :return: The feature_id of this ModelApplicationErrorOutputV1.
        :rtype: str
        """
        return self._feature_id

    @feature_id.setter
    def feature_id(self, feature_id):
        """
        Sets the feature_id of this ModelApplicationErrorOutputV1.
        UUID of the feature being evaluated when the error occurred.

        :param feature_id: The feature_id of this ModelApplicationErrorOutputV1.
        :type: str
        """

        self._feature_id = feature_id

    @property
    def message(self):
        """
        Gets the message of this ModelApplicationErrorOutputV1.
        Human-readable message describing the error.

        :return: The message of this ModelApplicationErrorOutputV1.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this ModelApplicationErrorOutputV1.
        Human-readable message describing the error.

        :param message: The message of this ModelApplicationErrorOutputV1.
        :type: str
        """

        self._message = message

    @property
    def message_arguments(self):
        """
        Gets the message_arguments of this ModelApplicationErrorOutputV1.
        Arguments for the message, if applicable.

        :return: The message_arguments of this ModelApplicationErrorOutputV1.
        :rtype: dict(str, str)
        """
        return self._message_arguments

    @message_arguments.setter
    def message_arguments(self, message_arguments):
        """
        Sets the message_arguments of this ModelApplicationErrorOutputV1.
        Arguments for the message, if applicable.

        :param message_arguments: The message_arguments of this ModelApplicationErrorOutputV1.
        :type: dict(str, str)
        """

        self._message_arguments = message_arguments

    @property
    def message_number(self):
        """
        Gets the message_number of this ModelApplicationErrorOutputV1.
        Message number for localization purposes.

        :return: The message_number of this ModelApplicationErrorOutputV1.
        :rtype: int
        """
        return self._message_number

    @message_number.setter
    def message_number(self, message_number):
        """
        Sets the message_number of this ModelApplicationErrorOutputV1.
        Message number for localization purposes.

        :param message_number: The message_number of this ModelApplicationErrorOutputV1.
        :type: int
        """

        self._message_number = message_number

    @property
    def model_id(self):
        """
        Gets the model_id of this ModelApplicationErrorOutputV1.
        UUID of the model that produced the error.

        :return: The model_id of this ModelApplicationErrorOutputV1.
        :rtype: str
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id):
        """
        Sets the model_id of this ModelApplicationErrorOutputV1.
        UUID of the model that produced the error.

        :param model_id: The model_id of this ModelApplicationErrorOutputV1.
        :type: str
        """

        self._model_id = model_id

    @property
    def rule_id(self):
        """
        Gets the rule_id of this ModelApplicationErrorOutputV1.
        UUID of the specific rule that failed or produced the error.

        :return: The rule_id of this ModelApplicationErrorOutputV1.
        :rtype: str
        """
        return self._rule_id

    @rule_id.setter
    def rule_id(self, rule_id):
        """
        Sets the rule_id of this ModelApplicationErrorOutputV1.
        UUID of the specific rule that failed or produced the error.

        :param rule_id: The rule_id of this ModelApplicationErrorOutputV1.
        :type: str
        """

        self._rule_id = rule_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ModelApplicationErrorOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
