# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class IssueSummaryOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _installed_on: str
    _issue_type: str
    _key: int
    _summary: str
    _version: str


    def __init__(
        self,
        installed_on: Optional[str] = None,
        issue_type: Optional[str] = None,
        key: Optional[int] = None,
        summary: Optional[str] = None,
        version: Optional[str] = None,
    ) -> None: ...

    @property
    def installed_on(self) -> str: ...

    @installed_on.setter
    def installed_on(self, installed_on: str) -> None: ...

    @property
    def issue_type(self) -> str: ...

    @issue_type.setter
    def issue_type(self, issue_type: str) -> None: ...

    @property
    def key(self) -> int: ...

    @key.setter
    def key(self, key: int) -> None: ...

    @property
    def summary(self) -> str: ...

    @summary.setter
    def summary(self, summary: str) -> None: ...

    @property
    def version(self) -> str: ...

    @version.setter
    def version(self, version: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
