# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class BoardTimeframeComparisonResultOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'baseline_range': 'str',
        'board_id': 'str',
        'board_name': 'str',
        'current_range': 'str',
        'tiles': 'list[BoardTimeframeComparisonTileOutputV1]',
        'tiles_analyzed': 'int',
        'tiles_skipped': 'int'
    }

    attribute_map = {
        'baseline_range': 'baselineRange',
        'board_id': 'boardId',
        'board_name': 'boardName',
        'current_range': 'currentRange',
        'tiles': 'tiles',
        'tiles_analyzed': 'tilesAnalyzed',
        'tiles_skipped': 'tilesSkipped'
    }

    def __init__(self, baseline_range=None, board_id=None, board_name=None, current_range=None, tiles=None, tiles_analyzed=None, tiles_skipped=None):
        """
        BoardTimeframeComparisonResultOutputV1 - a model defined in Swagger
        """

        self._baseline_range = None
        self._board_id = None
        self._board_name = None
        self._current_range = None
        self._tiles = None
        self._tiles_analyzed = None
        self._tiles_skipped = None

        if baseline_range is not None:
          self.baseline_range = baseline_range
        if board_id is not None:
          self.board_id = board_id
        if board_name is not None:
          self.board_name = board_name
        if current_range is not None:
          self.current_range = current_range
        if tiles is not None:
          self.tiles = tiles
        if tiles_analyzed is not None:
          self.tiles_analyzed = tiles_analyzed
        if tiles_skipped is not None:
          self.tiles_skipped = tiles_skipped

    @property
    def baseline_range(self):
        """
        Gets the baseline_range of this BoardTimeframeComparisonResultOutputV1.
        Baseline time range description

        :return: The baseline_range of this BoardTimeframeComparisonResultOutputV1.
        :rtype: str
        """
        return self._baseline_range

    @baseline_range.setter
    def baseline_range(self, baseline_range):
        """
        Sets the baseline_range of this BoardTimeframeComparisonResultOutputV1.
        Baseline time range description

        :param baseline_range: The baseline_range of this BoardTimeframeComparisonResultOutputV1.
        :type: str
        """
        if baseline_range is None:
            raise ValueError("Invalid value for `baseline_range`, must not be `None`")

        self._baseline_range = baseline_range

    @property
    def board_id(self):
        """
        Gets the board_id of this BoardTimeframeComparisonResultOutputV1.
        Board id

        :return: The board_id of this BoardTimeframeComparisonResultOutputV1.
        :rtype: str
        """
        return self._board_id

    @board_id.setter
    def board_id(self, board_id):
        """
        Sets the board_id of this BoardTimeframeComparisonResultOutputV1.
        Board id

        :param board_id: The board_id of this BoardTimeframeComparisonResultOutputV1.
        :type: str
        """
        if board_id is None:
            raise ValueError("Invalid value for `board_id`, must not be `None`")

        self._board_id = board_id

    @property
    def board_name(self):
        """
        Gets the board_name of this BoardTimeframeComparisonResultOutputV1.
        Board name

        :return: The board_name of this BoardTimeframeComparisonResultOutputV1.
        :rtype: str
        """
        return self._board_name

    @board_name.setter
    def board_name(self, board_name):
        """
        Sets the board_name of this BoardTimeframeComparisonResultOutputV1.
        Board name

        :param board_name: The board_name of this BoardTimeframeComparisonResultOutputV1.
        :type: str
        """
        if board_name is None:
            raise ValueError("Invalid value for `board_name`, must not be `None`")

        self._board_name = board_name

    @property
    def current_range(self):
        """
        Gets the current_range of this BoardTimeframeComparisonResultOutputV1.
        Current time range description

        :return: The current_range of this BoardTimeframeComparisonResultOutputV1.
        :rtype: str
        """
        return self._current_range

    @current_range.setter
    def current_range(self, current_range):
        """
        Sets the current_range of this BoardTimeframeComparisonResultOutputV1.
        Current time range description

        :param current_range: The current_range of this BoardTimeframeComparisonResultOutputV1.
        :type: str
        """
        if current_range is None:
            raise ValueError("Invalid value for `current_range`, must not be `None`")

        self._current_range = current_range

    @property
    def tiles(self):
        """
        Gets the tiles of this BoardTimeframeComparisonResultOutputV1.
        Per-tile comparison summaries

        :return: The tiles of this BoardTimeframeComparisonResultOutputV1.
        :rtype: list[BoardTimeframeComparisonTileOutputV1]
        """
        return self._tiles

    @tiles.setter
    def tiles(self, tiles):
        """
        Sets the tiles of this BoardTimeframeComparisonResultOutputV1.
        Per-tile comparison summaries

        :param tiles: The tiles of this BoardTimeframeComparisonResultOutputV1.
        :type: list[BoardTimeframeComparisonTileOutputV1]
        """
        if tiles is None:
            raise ValueError("Invalid value for `tiles`, must not be `None`")

        self._tiles = tiles

    @property
    def tiles_analyzed(self):
        """
        Gets the tiles_analyzed of this BoardTimeframeComparisonResultOutputV1.
        Number of tiles analyzed

        :return: The tiles_analyzed of this BoardTimeframeComparisonResultOutputV1.
        :rtype: int
        """
        return self._tiles_analyzed

    @tiles_analyzed.setter
    def tiles_analyzed(self, tiles_analyzed):
        """
        Sets the tiles_analyzed of this BoardTimeframeComparisonResultOutputV1.
        Number of tiles analyzed

        :param tiles_analyzed: The tiles_analyzed of this BoardTimeframeComparisonResultOutputV1.
        :type: int
        """
        if tiles_analyzed is None:
            raise ValueError("Invalid value for `tiles_analyzed`, must not be `None`")

        self._tiles_analyzed = tiles_analyzed

    @property
    def tiles_skipped(self):
        """
        Gets the tiles_skipped of this BoardTimeframeComparisonResultOutputV1.
        Number of tiles skipped

        :return: The tiles_skipped of this BoardTimeframeComparisonResultOutputV1.
        :rtype: int
        """
        return self._tiles_skipped

    @tiles_skipped.setter
    def tiles_skipped(self, tiles_skipped):
        """
        Sets the tiles_skipped of this BoardTimeframeComparisonResultOutputV1.
        Number of tiles skipped

        :param tiles_skipped: The tiles_skipped of this BoardTimeframeComparisonResultOutputV1.
        :type: int
        """
        if tiles_skipped is None:
            raise ValueError("Invalid value for `tiles_skipped`, must not be `None`")

        self._tiles_skipped = tiles_skipped

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, BoardTimeframeComparisonResultOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
