# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AnnotationOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _asset_selection_ids: List[str]
    _background: Optional[bool]
    _backups: List[DocumentBackupOutputV1]
    _ck_enabled: bool
    _content_ids: List[str]
    _created_at: Optional[str]
    _created_by: Optional[ItemPreviewV1]
    _cron_schedule: List[str]
    _date_range_ids: List[str]
    _description: Optional[str]
    _discoverable: Optional[bool]
    _document: Optional[str]
    _effective_permissions: Optional[PermissionsV1]
    _enabled: bool
    _fixed_width: bool
    _id: str
    _interests: List[AnnotationInterestOutputV1]
    _is_archived: Optional[bool]
    _is_redacted: Optional[bool]
    _margin_bottom: str
    _margin_left: str
    _margin_right: str
    _margin_top: str
    _name: str
    _next_run_time: Optional[str]
    _page_orientation: str
    _page_size: str
    _published_at: Optional[str]
    _replies: List[AnnotationOutputV1]
    _replies_to: Optional[str]
    _reports_on: Optional[str]
    _status_message: Optional[str]
    _timezone: Optional[str]
    _translation_key: Optional[str]
    _type: str
    _updated_at: Optional[str]


    def __init__(
        self,
        asset_selection_ids: Optional[List[str]] = None,
        background: Optional[bool] = False,
        backups: Optional[List[DocumentBackupOutputV1]] = None,
        ck_enabled: Optional[bool] = False,
        content_ids: Optional[List[str]] = None,
        created_at: Optional[str] = None,
        created_by: Optional[ItemPreviewV1] = None,
        cron_schedule: Optional[List[str]] = None,
        date_range_ids: Optional[List[str]] = None,
        description: Optional[str] = None,
        discoverable: Optional[bool] = False,
        document: Optional[str] = None,
        effective_permissions: Optional[PermissionsV1] = None,
        enabled: Optional[bool] = False,
        fixed_width: Optional[bool] = False,
        id: Optional[str] = None,
        interests: Optional[List[AnnotationInterestOutputV1]] = None,
        is_archived: Optional[bool] = False,
        is_redacted: Optional[bool] = False,
        margin_bottom: Optional[str] = '0.5in',
        margin_left: Optional[str] = '0.5in',
        margin_right: Optional[str] = '0.5in',
        margin_top: Optional[str] = '0.5in',
        name: Optional[str] = None,
        next_run_time: Optional[str] = None,
        page_orientation: Optional[str] = 'Portrait',
        page_size: Optional[str] = 'Letter',
        published_at: Optional[str] = None,
        replies: Optional[List[AnnotationOutputV1]] = None,
        replies_to: Optional[str] = None,
        reports_on: Optional[str] = None,
        status_message: Optional[str] = None,
        timezone: Optional[str] = None,
        translation_key: Optional[str] = None,
        type: Optional[str] = None,
        updated_at: Optional[str] = None,
    ) -> None: ...

    @property
    def asset_selection_ids(self) -> List[str]: ...

    @asset_selection_ids.setter
    def asset_selection_ids(self, asset_selection_ids: List[str]) -> None: ...

    @property
    def background(self) -> Optional[bool]: ...

    @background.setter
    def background(self, background: Optional[bool]) -> None: ...

    @property
    def backups(self) -> List[DocumentBackupOutputV1]: ...

    @backups.setter
    def backups(self, backups: List[DocumentBackupOutputV1]) -> None: ...

    @property
    def ck_enabled(self) -> bool: ...

    @ck_enabled.setter
    def ck_enabled(self, ck_enabled: bool) -> None: ...

    @property
    def content_ids(self) -> List[str]: ...

    @content_ids.setter
    def content_ids(self, content_ids: List[str]) -> None: ...

    @property
    def created_at(self) -> Optional[str]: ...

    @created_at.setter
    def created_at(self, created_at: Optional[str]) -> None: ...

    @property
    def created_by(self) -> Optional[ItemPreviewV1]: ...

    @created_by.setter
    def created_by(self, created_by: Optional[ItemPreviewV1]) -> None: ...

    @property
    def cron_schedule(self) -> List[str]: ...

    @cron_schedule.setter
    def cron_schedule(self, cron_schedule: List[str]) -> None: ...

    @property
    def date_range_ids(self) -> List[str]: ...

    @date_range_ids.setter
    def date_range_ids(self, date_range_ids: List[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def discoverable(self) -> Optional[bool]: ...

    @discoverable.setter
    def discoverable(self, discoverable: Optional[bool]) -> None: ...

    @property
    def document(self) -> Optional[str]: ...

    @document.setter
    def document(self, document: Optional[str]) -> None: ...

    @property
    def effective_permissions(self) -> Optional[PermissionsV1]: ...

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions: Optional[PermissionsV1]) -> None: ...

    @property
    def enabled(self) -> bool: ...

    @enabled.setter
    def enabled(self, enabled: bool) -> None: ...

    @property
    def fixed_width(self) -> bool: ...

    @fixed_width.setter
    def fixed_width(self, fixed_width: bool) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def interests(self) -> List[AnnotationInterestOutputV1]: ...

    @interests.setter
    def interests(self, interests: List[AnnotationInterestOutputV1]) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def is_redacted(self) -> Optional[bool]: ...

    @is_redacted.setter
    def is_redacted(self, is_redacted: Optional[bool]) -> None: ...

    @property
    def margin_bottom(self) -> str: ...

    @margin_bottom.setter
    def margin_bottom(self, margin_bottom: str) -> None: ...

    @property
    def margin_left(self) -> str: ...

    @margin_left.setter
    def margin_left(self, margin_left: str) -> None: ...

    @property
    def margin_right(self) -> str: ...

    @margin_right.setter
    def margin_right(self, margin_right: str) -> None: ...

    @property
    def margin_top(self) -> str: ...

    @margin_top.setter
    def margin_top(self, margin_top: str) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def next_run_time(self) -> Optional[str]: ...

    @next_run_time.setter
    def next_run_time(self, next_run_time: Optional[str]) -> None: ...

    @property
    def page_orientation(self) -> str: ...

    @page_orientation.setter
    def page_orientation(self, page_orientation: str) -> None: ...

    @property
    def page_size(self) -> str: ...

    @page_size.setter
    def page_size(self, page_size: str) -> None: ...

    @property
    def published_at(self) -> Optional[str]: ...

    @published_at.setter
    def published_at(self, published_at: Optional[str]) -> None: ...

    @property
    def replies(self) -> List[AnnotationOutputV1]: ...

    @replies.setter
    def replies(self, replies: List[AnnotationOutputV1]) -> None: ...

    @property
    def replies_to(self) -> Optional[str]: ...

    @replies_to.setter
    def replies_to(self, replies_to: Optional[str]) -> None: ...

    @property
    def reports_on(self) -> Optional[str]: ...

    @reports_on.setter
    def reports_on(self, reports_on: Optional[str]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def timezone(self) -> Optional[str]: ...

    @timezone.setter
    def timezone(self, timezone: Optional[str]) -> None: ...

    @property
    def translation_key(self) -> Optional[str]: ...

    @translation_key.setter
    def translation_key(self, translation_key: Optional[str]) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    @property
    def updated_at(self) -> Optional[str]: ...

    @updated_at.setter
    def updated_at(self, updated_at: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
