# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ItemWithSwapPairsV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _item: ItemPreviewWithAssetsV1
    _parameter_match: float
    _swap_pairs: List[SwapInputV1]


    def __init__(
        self,
        item: Optional[ItemPreviewWithAssetsV1] = None,
        parameter_match: Optional[float] = None,
        swap_pairs: Optional[List[SwapInputV1]] = None,
    ) -> None: ...

    @property
    def item(self) -> ItemPreviewWithAssetsV1: ...

    @item.setter
    def item(self, item: ItemPreviewWithAssetsV1) -> None: ...

    @property
    def parameter_match(self) -> float: ...

    @parameter_match.setter
    def parameter_match(self, parameter_match: float) -> None: ...

    @property
    def swap_pairs(self) -> List[SwapInputV1]: ...

    @swap_pairs.setter
    def swap_pairs(self, swap_pairs: List[SwapInputV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
