# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ConditionTableInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'capsule_properties': 'list[str]',
        'condition_properties': 'list[str]',
        'condition_source': 'ConditionSourceV1',
        'end': 'Value',
        'filter': 'Filter',
        'include_asset_column': 'bool',
        'limit': 'int',
        'start': 'Value'
    }

    attribute_map = {
        'capsule_properties': 'capsuleProperties',
        'condition_properties': 'conditionProperties',
        'condition_source': 'conditionSource',
        'end': 'end',
        'filter': 'filter',
        'include_asset_column': 'includeAssetColumn',
        'limit': 'limit',
        'start': 'start'
    }

    def __init__(self, capsule_properties=None, condition_properties=None, condition_source=None, end=None, filter=None, include_asset_column=True, limit=40, start=None):
        """
        ConditionTableInputV1 - a model defined in Swagger
        """

        self._capsule_properties = None
        self._condition_properties = None
        self._condition_source = None
        self._end = None
        self._filter = None
        self._include_asset_column = None
        self._limit = None
        self._start = None

        if capsule_properties is not None:
          self.capsule_properties = capsule_properties
        if condition_properties is not None:
          self.condition_properties = condition_properties
        if condition_source is not None:
          self.condition_source = condition_source
        if end is not None:
          self.end = end
        if filter is not None:
          self.filter = filter
        if include_asset_column is not None:
          self.include_asset_column = include_asset_column
        if limit is not None:
          self.limit = limit
        if start is not None:
          self.start = start

    @property
    def capsule_properties(self):
        """
        Gets the capsule_properties of this ConditionTableInputV1.
        The list of capsule properties to include in the resulting table

        :return: The capsule_properties of this ConditionTableInputV1.
        :rtype: list[str]
        """
        return self._capsule_properties

    @capsule_properties.setter
    def capsule_properties(self, capsule_properties):
        """
        Sets the capsule_properties of this ConditionTableInputV1.
        The list of capsule properties to include in the resulting table

        :param capsule_properties: The capsule_properties of this ConditionTableInputV1.
        :type: list[str]
        """

        self._capsule_properties = capsule_properties

    @property
    def condition_properties(self):
        """
        Gets the condition_properties of this ConditionTableInputV1.
        The list of condition properties that will be concatenated onto each resulting capsule row

        :return: The condition_properties of this ConditionTableInputV1.
        :rtype: list[str]
        """
        return self._condition_properties

    @condition_properties.setter
    def condition_properties(self, condition_properties):
        """
        Sets the condition_properties of this ConditionTableInputV1.
        The list of condition properties that will be concatenated onto each resulting capsule row

        :param condition_properties: The condition_properties of this ConditionTableInputV1.
        :type: list[str]
        """

        self._condition_properties = condition_properties

    @property
    def condition_source(self):
        """
        Gets the condition_source of this ConditionTableInputV1.

        :return: The condition_source of this ConditionTableInputV1.
        :rtype: ConditionSourceV1
        """
        return self._condition_source

    @condition_source.setter
    def condition_source(self, condition_source):
        """
        Sets the condition_source of this ConditionTableInputV1.

        :param condition_source: The condition_source of this ConditionTableInputV1.
        :type: ConditionSourceV1
        """
        if condition_source is None:
            raise ValueError("Invalid value for `condition_source`, must not be `None`")

        self._condition_source = condition_source

    @property
    def end(self):
        """
        Gets the end of this ConditionTableInputV1.

        :return: The end of this ConditionTableInputV1.
        :rtype: Value
        """
        return self._end

    @end.setter
    def end(self, end):
        """
        Sets the end of this ConditionTableInputV1.

        :param end: The end of this ConditionTableInputV1.
        :type: Value
        """
        if end is None:
            raise ValueError("Invalid value for `end`, must not be `None`")

        self._end = end

    @property
    def filter(self):
        """
        Gets the filter of this ConditionTableInputV1.

        :return: The filter of this ConditionTableInputV1.
        :rtype: Filter
        """
        return self._filter

    @filter.setter
    def filter(self, filter):
        """
        Sets the filter of this ConditionTableInputV1.

        :param filter: The filter of this ConditionTableInputV1.
        :type: Filter
        """

        self._filter = filter

    @property
    def include_asset_column(self):
        """
        Gets the include_asset_column of this ConditionTableInputV1.
        Include asset column in results when running across assets

        :return: The include_asset_column of this ConditionTableInputV1.
        :rtype: bool
        """
        return self._include_asset_column

    @include_asset_column.setter
    def include_asset_column(self, include_asset_column):
        """
        Sets the include_asset_column of this ConditionTableInputV1.
        Include asset column in results when running across assets

        :param include_asset_column: The include_asset_column of this ConditionTableInputV1.
        :type: bool
        """

        self._include_asset_column = include_asset_column

    @property
    def limit(self):
        """
        Gets the limit of this ConditionTableInputV1.
        Maximum number of rows to return

        :return: The limit of this ConditionTableInputV1.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """
        Sets the limit of this ConditionTableInputV1.
        Maximum number of rows to return

        :param limit: The limit of this ConditionTableInputV1.
        :type: int
        """
        if limit is None:
            raise ValueError("Invalid value for `limit`, must not be `None`")

        self._limit = limit

    @property
    def start(self):
        """
        Gets the start of this ConditionTableInputV1.

        :return: The start of this ConditionTableInputV1.
        :rtype: Value
        """
        return self._start

    @start.setter
    def start(self, start):
        """
        Sets the start of this ConditionTableInputV1.

        :param start: The start of this ConditionTableInputV1.
        :type: Value
        """
        if start is None:
            raise ValueError("Invalid value for `start`, must not be `None`")

        self._start = start

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ConditionTableInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
