# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class BoardsApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def compare_board_timeframes(
        self,
        **kwargs: Any,
    ) -> BoardTimeframeComparisonResultOutputV1: ...

    def compare_board_timeframes_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_board(
        self,
        **kwargs: Any,
    ) -> BoardOutputV1: ...

    def create_board_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_board_filter(
        self,
        **kwargs: Any,
    ) -> BoardFilterOutputV1: ...

    def create_board_filter_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_tile(
        self,
        **kwargs: Any,
    ) -> TileOutputV1: ...

    def create_tile_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_board(
        self,
        **kwargs: Any,
    ) -> DeleteResultOutputV1: ...

    def delete_board_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_board_filter(
        self,
        **kwargs: Any,
    ) -> DeleteResultOutputV1: ...

    def delete_board_filter_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_tile(
        self,
        **kwargs: Any,
    ) -> DeleteResultOutputV1: ...

    def delete_tile_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def generate_chart_data(
        self,
        **kwargs: Any,
    ) -> ChartDataResultOutputV1: ...

    def generate_chart_data_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_board(
        self,
        **kwargs: Any,
    ) -> BoardOutputV1: ...

    def get_board_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_board_column_values(
        self,
        **kwargs: Any,
    ) -> ColumnValuesOutputV1: ...

    def get_board_column_values_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_board_shared_columns(
        self,
        **kwargs: Any,
    ) -> SharedColumnsOutputV1: ...

    def get_board_shared_columns_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_board_tile_layout(
        self,
        **kwargs: Any,
    ) -> TileLayoutOutputV1: ...

    def get_board_tile_layout_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_boards(
        self,
        **kwargs: Any,
    ) -> BoardOutputV1: ...

    def get_boards_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_tile(
        self,
        **kwargs: Any,
    ) -> TileOutputV1: ...

    def get_tile_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_board(
        self,
        **kwargs: Any,
    ) -> BoardOutputV1: ...

    def update_board_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_board_filter(
        self,
        **kwargs: Any,
    ) -> BoardFilterOutputV1: ...

    def update_board_filter_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_tile(
        self,
        **kwargs: Any,
    ) -> TileOutputV1: ...

    def update_tile_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
