# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class DatasourceInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _additional_properties: Optional[List[ScalarPropertyV1]]
    _cache_enabled: Optional[bool]
    _condition_location: Optional[str]
    _datasource_class: str
    _datasource_id: str
    _description: Optional[str]
    _indexing_schedule_supported: Optional[bool]
    _name: str
    _signal_location: Optional[str]
    _stored_in_seeq: Optional[bool]


    def __init__(
        self,
        additional_properties: Optional[List[ScalarPropertyV1]] = None,
        cache_enabled: Optional[bool] = None,
        condition_location: Optional[str] = None,
        datasource_class: Optional[str] = None,
        datasource_id: Optional[str] = None,
        description: Optional[str] = None,
        indexing_schedule_supported: Optional[bool] = False,
        name: Optional[str] = None,
        signal_location: Optional[str] = None,
        stored_in_seeq: Optional[bool] = False,
    ) -> None: ...

    @property
    def additional_properties(self) -> Optional[List[ScalarPropertyV1]]: ...

    @additional_properties.setter
    def additional_properties(self, additional_properties: Optional[List[ScalarPropertyV1]]) -> None: ...

    @property
    def cache_enabled(self) -> Optional[bool]: ...

    @cache_enabled.setter
    def cache_enabled(self, cache_enabled: Optional[bool]) -> None: ...

    @property
    def condition_location(self) -> Optional[str]: ...

    @condition_location.setter
    def condition_location(self, condition_location: Optional[str]) -> None: ...

    @property
    def datasource_class(self) -> str: ...

    @datasource_class.setter
    def datasource_class(self, datasource_class: str) -> None: ...

    @property
    def datasource_id(self) -> str: ...

    @datasource_id.setter
    def datasource_id(self, datasource_id: str) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def indexing_schedule_supported(self) -> Optional[bool]: ...

    @indexing_schedule_supported.setter
    def indexing_schedule_supported(self, indexing_schedule_supported: Optional[bool]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def signal_location(self) -> Optional[str]: ...

    @signal_location.setter
    def signal_location(self, signal_location: Optional[str]) -> None: ...

    @property
    def stored_in_seeq(self) -> Optional[bool]: ...

    @stored_in_seeq.setter
    def stored_in_seeq(self, stored_in_seeq: Optional[bool]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
