# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ItemFinderSearchesInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _fixed_list_searches: Optional[List[FixedListSearchV1]]
    _limit: Optional[int]
    _property_searches: Optional[List[PropertySearchV1]]
    _scaling_table_uuid_column_searches: Optional[List[ScalingTableUUIDColumnSearchV1]]
    _searches: Optional[List[SwapAcrossAssetsSearchV1]]
    _stored_table_searches: Optional[List[StoredTableSearchV1]]


    def __init__(
        self,
        fixed_list_searches: Optional[List[FixedListSearchV1]] = None,
        limit: Optional[int] = 40,
        property_searches: Optional[List[PropertySearchV1]] = None,
        scaling_table_uuid_column_searches: Optional[List[ScalingTableUUIDColumnSearchV1]] = None,
        searches: Optional[List[SwapAcrossAssetsSearchV1]] = None,
        stored_table_searches: Optional[List[StoredTableSearchV1]] = None,
    ) -> None: ...

    @property
    def fixed_list_searches(self) -> Optional[List[FixedListSearchV1]]: ...

    @fixed_list_searches.setter
    def fixed_list_searches(self, fixed_list_searches: Optional[List[FixedListSearchV1]]) -> None: ...

    @property
    def limit(self) -> Optional[int]: ...

    @limit.setter
    def limit(self, limit: Optional[int]) -> None: ...

    @property
    def property_searches(self) -> Optional[List[PropertySearchV1]]: ...

    @property_searches.setter
    def property_searches(self, property_searches: Optional[List[PropertySearchV1]]) -> None: ...

    @property
    def scaling_table_uuid_column_searches(self) -> Optional[List[ScalingTableUUIDColumnSearchV1]]: ...

    @scaling_table_uuid_column_searches.setter
    def scaling_table_uuid_column_searches(self, scaling_table_uuid_column_searches: Optional[List[ScalingTableUUIDColumnSearchV1]]) -> None: ...

    @property
    def searches(self) -> Optional[List[SwapAcrossAssetsSearchV1]]: ...

    @searches.setter
    def searches(self, searches: Optional[List[SwapAcrossAssetsSearchV1]]) -> None: ...

    @property
    def stored_table_searches(self) -> Optional[List[StoredTableSearchV1]]: ...

    @stored_table_searches.setter
    def stored_table_searches(self, stored_table_searches: Optional[List[StoredTableSearchV1]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
