# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ScheduledNotebookOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _average_run_time: Optional[int]
    _created_at: Optional[str]
    _description: Optional[str]
    _effective_permissions: Optional[PermissionsV1]
    _enabled: Optional[bool]
    _file_path: Optional[str]
    _id: str
    _is_archived: Optional[bool]
    _is_redacted: Optional[bool]
    _label: Optional[str]
    _last_run_at: Optional[str]
    _name: str
    _notify_on_automatic_unschedule: Optional[bool]
    _notify_on_skipped_execution: Optional[bool]
    _project: Optional[ItemPreviewV1]
    _run_errors: Optional[Dict[str, str]]
    _run_user: Optional[IdentityPreviewV1]
    _run_warnings: Optional[Dict[str, str]]
    _scheduled_at: Optional[str]
    _schedules: Optional[List[ScheduleOutputV1]]
    _status_message: Optional[str]
    _timezone: Optional[str]
    _total_run_time: Optional[int]
    _translation_key: Optional[str]
    _type: str
    _updated_at: Optional[str]


    def __init__(
        self,
        average_run_time: Optional[int] = None,
        created_at: Optional[str] = None,
        description: Optional[str] = None,
        effective_permissions: Optional[PermissionsV1] = None,
        enabled: Optional[bool] = True,
        file_path: Optional[str] = None,
        id: Optional[str] = None,
        is_archived: Optional[bool] = False,
        is_redacted: Optional[bool] = False,
        label: Optional[str] = None,
        last_run_at: Optional[str] = None,
        name: Optional[str] = None,
        notify_on_automatic_unschedule: Optional[bool] = False,
        notify_on_skipped_execution: Optional[bool] = False,
        project: Optional[ItemPreviewV1] = None,
        run_errors: Optional[Dict[str, str]] = None,
        run_user: Optional[IdentityPreviewV1] = None,
        run_warnings: Optional[Dict[str, str]] = None,
        scheduled_at: Optional[str] = None,
        schedules: Optional[List[ScheduleOutputV1]] = None,
        status_message: Optional[str] = None,
        timezone: Optional[str] = None,
        total_run_time: Optional[int] = None,
        translation_key: Optional[str] = None,
        type: Optional[str] = None,
        updated_at: Optional[str] = None,
    ) -> None: ...

    @property
    def average_run_time(self) -> Optional[int]: ...

    @average_run_time.setter
    def average_run_time(self, average_run_time: Optional[int]) -> None: ...

    @property
    def created_at(self) -> Optional[str]: ...

    @created_at.setter
    def created_at(self, created_at: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def effective_permissions(self) -> Optional[PermissionsV1]: ...

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions: Optional[PermissionsV1]) -> None: ...

    @property
    def enabled(self) -> Optional[bool]: ...

    @enabled.setter
    def enabled(self, enabled: Optional[bool]) -> None: ...

    @property
    def file_path(self) -> Optional[str]: ...

    @file_path.setter
    def file_path(self, file_path: Optional[str]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def is_redacted(self) -> Optional[bool]: ...

    @is_redacted.setter
    def is_redacted(self, is_redacted: Optional[bool]) -> None: ...

    @property
    def label(self) -> Optional[str]: ...

    @label.setter
    def label(self, label: Optional[str]) -> None: ...

    @property
    def last_run_at(self) -> Optional[str]: ...

    @last_run_at.setter
    def last_run_at(self, last_run_at: Optional[str]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def notify_on_automatic_unschedule(self) -> Optional[bool]: ...

    @notify_on_automatic_unschedule.setter
    def notify_on_automatic_unschedule(self, notify_on_automatic_unschedule: Optional[bool]) -> None: ...

    @property
    def notify_on_skipped_execution(self) -> Optional[bool]: ...

    @notify_on_skipped_execution.setter
    def notify_on_skipped_execution(self, notify_on_skipped_execution: Optional[bool]) -> None: ...

    @property
    def project(self) -> Optional[ItemPreviewV1]: ...

    @project.setter
    def project(self, project: Optional[ItemPreviewV1]) -> None: ...

    @property
    def run_errors(self) -> Optional[Dict[str, str]]: ...

    @run_errors.setter
    def run_errors(self, run_errors: Optional[Dict[str, str]]) -> None: ...

    @property
    def run_user(self) -> Optional[IdentityPreviewV1]: ...

    @run_user.setter
    def run_user(self, run_user: Optional[IdentityPreviewV1]) -> None: ...

    @property
    def run_warnings(self) -> Optional[Dict[str, str]]: ...

    @run_warnings.setter
    def run_warnings(self, run_warnings: Optional[Dict[str, str]]) -> None: ...

    @property
    def scheduled_at(self) -> Optional[str]: ...

    @scheduled_at.setter
    def scheduled_at(self, scheduled_at: Optional[str]) -> None: ...

    @property
    def schedules(self) -> Optional[List[ScheduleOutputV1]]: ...

    @schedules.setter
    def schedules(self, schedules: Optional[List[ScheduleOutputV1]]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def timezone(self) -> Optional[str]: ...

    @timezone.setter
    def timezone(self, timezone: Optional[str]) -> None: ...

    @property
    def total_run_time(self) -> Optional[int]: ...

    @total_run_time.setter
    def total_run_time(self, total_run_time: Optional[int]) -> None: ...

    @property
    def translation_key(self) -> Optional[str]: ...

    @translation_key.setter
    def translation_key(self, translation_key: Optional[str]) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    @property
    def updated_at(self) -> Optional[str]: ...

    @updated_at.setter
    def updated_at(self, updated_at: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
