# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class TreemapItemOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _asset: Optional[AssetOutputV1]
    _display_scalars: Optional[List[ScalarValueOutputV1]]
    _is_leaf_asset: Optional[bool]
    _priority: Optional[int]
    _size: Optional[Any]
    _uncertain: Optional[bool]


    def __init__(
        self,
        asset: Optional[AssetOutputV1] = None,
        display_scalars: Optional[List[ScalarValueOutputV1]] = None,
        is_leaf_asset: Optional[bool] = None,
        priority: Optional[int] = None,
        size: Optional[Any] = None,
        uncertain: Optional[bool] = False,
    ) -> None: ...

    @property
    def asset(self) -> Optional[AssetOutputV1]: ...

    @asset.setter
    def asset(self, asset: Optional[AssetOutputV1]) -> None: ...

    @property
    def display_scalars(self) -> Optional[List[ScalarValueOutputV1]]: ...

    @display_scalars.setter
    def display_scalars(self, display_scalars: Optional[List[ScalarValueOutputV1]]) -> None: ...

    @property
    def is_leaf_asset(self) -> Optional[bool]: ...

    @is_leaf_asset.setter
    def is_leaf_asset(self, is_leaf_asset: Optional[bool]) -> None: ...

    @property
    def priority(self) -> Optional[int]: ...

    @priority.setter
    def priority(self, priority: Optional[int]) -> None: ...

    @property
    def size(self) -> Optional[Any]: ...

    @size.setter
    def size(self, size: Optional[Any]) -> None: ...

    @property
    def uncertain(self) -> Optional[bool]: ...

    @uncertain.setter
    def uncertain(self, uncertain: Optional[bool]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
