# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class DateRangeInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _archived: Optional[bool]
    _background: Optional[bool]
    _condition_id: Optional[str]
    _cron_schedule: Optional[List[str]]
    _description: Optional[str]
    _enabled: Optional[bool]
    _formula: str
    _name: str
    _report_id: Optional[str]


    def __init__(
        self,
        archived: Optional[bool] = False,
        background: Optional[bool] = False,
        condition_id: Optional[str] = None,
        cron_schedule: Optional[List[str]] = None,
        description: Optional[str] = None,
        enabled: Optional[bool] = True,
        formula: Optional[str] = None,
        name: Optional[str] = None,
        report_id: Optional[str] = None,
    ) -> None: ...

    @property
    def archived(self) -> Optional[bool]: ...

    @archived.setter
    def archived(self, archived: Optional[bool]) -> None: ...

    @property
    def background(self) -> Optional[bool]: ...

    @background.setter
    def background(self, background: Optional[bool]) -> None: ...

    @property
    def condition_id(self) -> Optional[str]: ...

    @condition_id.setter
    def condition_id(self, condition_id: Optional[str]) -> None: ...

    @property
    def cron_schedule(self) -> Optional[List[str]]: ...

    @cron_schedule.setter
    def cron_schedule(self, cron_schedule: Optional[List[str]]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def enabled(self) -> Optional[bool]: ...

    @enabled.setter
    def enabled(self, enabled: Optional[bool]) -> None: ...

    @property
    def formula(self) -> str: ...

    @formula.setter
    def formula(self, formula: str) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def report_id(self) -> Optional[str]: ...

    @report_id.setter
    def report_id(self, report_id: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
