# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, Optional


class RESTResponse(object):
    status: int
    reason: str
    data: Any

    def __init__(self, resp: Any) -> None: ...

    @property
    def headers(self) -> Any: ...

    def getheaders(self) -> Any: ...
    def getheader(self, name: str, default: Optional[Any] = None) -> Any: ...


class RESTClientObject(object):
    configuration: Any

    def __init__(self, configuration: Any, pools_size: int = 4, maxsize: int = 4) -> None: ...

    def request(
        self,
        method: str,
        url: str,
        query_params: Any = None,
        headers: Optional[Dict[str, Any]] = None,
        body: Any = None,
        post_params: Any = None,
        _preload_content: bool = True,
        _request_timeout: Any = None,
    ) -> Any: ...


class ApiException(Exception):
    status: Optional[int]
    reason: Optional[str]
    body: Any
    headers: Any

    def __init__(self, status: Optional[int] = None, reason: Optional[str] = None, http_resp: Any = None) -> None: ...
    def __str__(self) -> str: ...
