# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class SignalMonitorMetadataOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _creator: Optional[IdentityPreviewV1]
    _enabled: bool
    _id: str
    _name: str
    _signal_ids: List[str]
    _workbook: Optional[SignalMonitorWorkbookOutputV1]
    _workbooks: Dict[str, str]


    def __init__(
        self,
        creator: Optional[IdentityPreviewV1] = None,
        enabled: Optional[bool] = None,
        id: Optional[str] = None,
        name: Optional[str] = None,
        signal_ids: Optional[List[str]] = None,
        workbook: Optional[SignalMonitorWorkbookOutputV1] = None,
        workbooks: Optional[Dict[str, str]] = None,
    ) -> None: ...

    @property
    def creator(self) -> Optional[IdentityPreviewV1]: ...

    @creator.setter
    def creator(self, creator: Optional[IdentityPreviewV1]) -> None: ...

    @property
    def enabled(self) -> bool: ...

    @enabled.setter
    def enabled(self, enabled: bool) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def signal_ids(self) -> List[str]: ...

    @signal_ids.setter
    def signal_ids(self, signal_ids: List[str]) -> None: ...

    @property
    def workbook(self) -> Optional[SignalMonitorWorkbookOutputV1]: ...

    @workbook.setter
    def workbook(self, workbook: Optional[SignalMonitorWorkbookOutputV1]) -> None: ...

    @property
    def workbooks(self) -> Dict[str, str]: ...

    @workbooks.setter
    def workbooks(self, workbooks: Dict[str, str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
