# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class RehydrationInstructionsInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _lookup: Optional[List[RehydrationSeriesLookupInputV1]]
    _map_marker: Optional[MapMarkerRehydrationInstructionsInputV1]
    _radial: Optional[RadialRehydrationInstructionsInputV1]
    _radial_gauge: Optional[RadialGaugeRehydrationInstructionsInputV1]
    _series_identifier: Optional[str]


    def __init__(
        self,
        lookup: Optional[List[RehydrationSeriesLookupInputV1]] = None,
        map_marker: Optional[MapMarkerRehydrationInstructionsInputV1] = None,
        radial: Optional[RadialRehydrationInstructionsInputV1] = None,
        radial_gauge: Optional[RadialGaugeRehydrationInstructionsInputV1] = None,
        series_identifier: Optional[str] = None,
    ) -> None: ...

    @property
    def lookup(self) -> Optional[List[RehydrationSeriesLookupInputV1]]: ...

    @lookup.setter
    def lookup(self, lookup: Optional[List[RehydrationSeriesLookupInputV1]]) -> None: ...

    @property
    def map_marker(self) -> Optional[MapMarkerRehydrationInstructionsInputV1]: ...

    @map_marker.setter
    def map_marker(self, map_marker: Optional[MapMarkerRehydrationInstructionsInputV1]) -> None: ...

    @property
    def radial(self) -> Optional[RadialRehydrationInstructionsInputV1]: ...

    @radial.setter
    def radial(self, radial: Optional[RadialRehydrationInstructionsInputV1]) -> None: ...

    @property
    def radial_gauge(self) -> Optional[RadialGaugeRehydrationInstructionsInputV1]: ...

    @radial_gauge.setter
    def radial_gauge(self, radial_gauge: Optional[RadialGaugeRehydrationInstructionsInputV1]) -> None: ...

    @property
    def series_identifier(self) -> Optional[str]: ...

    @series_identifier.setter
    def series_identifier(self, series_identifier: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
