# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ConnectionStatusV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _agent_version_required: Optional[str]
    _connection_message: Optional[str]
    _connector_developer_name: Optional[str]
    _connector_developer_support_url: Optional[str]
    _datasource_class: str
    _datasource_id: str
    _id: str
    _indexing_datasource_connection: bool
    _name: str
    _pull_datasource_connection: bool
    _reinitialized: bool
    _status: Optional[str]
    _sync_progress: Optional[SyncProgress]
    _sync_status: Optional[str]
    _version: Optional[str]


    def __init__(
        self,
        agent_version_required: Optional[str] = None,
        connection_message: Optional[str] = None,
        connector_developer_name: Optional[str] = None,
        connector_developer_support_url: Optional[str] = None,
        datasource_class: Optional[str] = None,
        datasource_id: Optional[str] = None,
        id: Optional[str] = None,
        indexing_datasource_connection: Optional[bool] = False,
        name: Optional[str] = None,
        pull_datasource_connection: Optional[bool] = False,
        reinitialized: Optional[bool] = False,
        status: Optional[str] = None,
        sync_progress: Optional[SyncProgress] = None,
        sync_status: Optional[str] = None,
        version: Optional[str] = None,
    ) -> None: ...

    @property
    def agent_version_required(self) -> Optional[str]: ...

    @agent_version_required.setter
    def agent_version_required(self, agent_version_required: Optional[str]) -> None: ...

    @property
    def connection_message(self) -> Optional[str]: ...

    @connection_message.setter
    def connection_message(self, connection_message: Optional[str]) -> None: ...

    @property
    def connector_developer_name(self) -> Optional[str]: ...

    @connector_developer_name.setter
    def connector_developer_name(self, connector_developer_name: Optional[str]) -> None: ...

    @property
    def connector_developer_support_url(self) -> Optional[str]: ...

    @connector_developer_support_url.setter
    def connector_developer_support_url(self, connector_developer_support_url: Optional[str]) -> None: ...

    @property
    def datasource_class(self) -> str: ...

    @datasource_class.setter
    def datasource_class(self, datasource_class: str) -> None: ...

    @property
    def datasource_id(self) -> str: ...

    @datasource_id.setter
    def datasource_id(self, datasource_id: str) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def indexing_datasource_connection(self) -> bool: ...

    @indexing_datasource_connection.setter
    def indexing_datasource_connection(self, indexing_datasource_connection: bool) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def pull_datasource_connection(self) -> bool: ...

    @pull_datasource_connection.setter
    def pull_datasource_connection(self, pull_datasource_connection: bool) -> None: ...

    @property
    def reinitialized(self) -> bool: ...

    @reinitialized.setter
    def reinitialized(self, reinitialized: bool) -> None: ...

    @property
    def status(self) -> Optional[str]: ...

    @status.setter
    def status(self, status: Optional[str]) -> None: ...

    @property
    def sync_progress(self) -> Optional[SyncProgress]: ...

    @sync_progress.setter
    def sync_progress(self, sync_progress: Optional[SyncProgress]) -> None: ...

    @property
    def sync_status(self) -> Optional[str]: ...

    @sync_status.setter
    def sync_status(self, sync_status: Optional[str]) -> None: ...

    @property
    def version(self) -> Optional[str]: ...

    @version.setter
    def version(self, version: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
