# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AclInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _disable_permission_inheritance: Optional[bool]
    _entries: Optional[List[AceInputV1]]
    _localize_inherited: Optional[bool]
    _preview: Optional[bool]


    def __init__(
        self,
        disable_permission_inheritance: Optional[bool] = False,
        entries: Optional[List[AceInputV1]] = None,
        localize_inherited: Optional[bool] = False,
        preview: Optional[bool] = False,
    ) -> None: ...

    @property
    def disable_permission_inheritance(self) -> Optional[bool]: ...

    @disable_permission_inheritance.setter
    def disable_permission_inheritance(self, disable_permission_inheritance: Optional[bool]) -> None: ...

    @property
    def entries(self) -> Optional[List[AceInputV1]]: ...

    @entries.setter
    def entries(self, entries: Optional[List[AceInputV1]]) -> None: ...

    @property
    def localize_inherited(self) -> Optional[bool]: ...

    @localize_inherited.setter
    def localize_inherited(self, localize_inherited: Optional[bool]) -> None: ...

    @property
    def preview(self) -> Optional[bool]: ...

    @preview.setter
    def preview(self, preview: Optional[bool]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
