# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class SystemApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def create_add_on_tool(
        self,
        **kwargs: Any,
    ) -> AddOnToolOutputV1: ...

    def create_add_on_tool_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_add_on_tool(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_add_on_tool_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def disable_licensed_feature(
        self,
        **kwargs: Any,
    ) -> None: ...

    def disable_licensed_feature_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def enable_licensed_feature(
        self,
        **kwargs: Any,
    ) -> None: ...

    def enable_licensed_feature_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_add_on_tool(
        self,
        **kwargs: Any,
    ) -> AddOnToolOutputV1: ...

    def get_add_on_tool_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_add_on_tools(
        self,
        **kwargs: Any,
    ) -> GetAddOnToolsOutputV1: ...

    def get_add_on_tools_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_administrator_contact_information(
        self,
        **kwargs: Any,
    ) -> AdministratorContactInformationV1: ...

    def get_administrator_contact_information_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_agent_key(
        self,
        **kwargs: Any,
    ) -> AgentKeyOutputV1: ...

    def get_agent_key_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_build_info(
        self,
        **kwargs: Any,
    ) -> ServerBuildInfoOutputV1: ...

    def get_build_info_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_configuration_options(
        self,
        **kwargs: Any,
    ) -> ConfigurationOutputV1: ...

    def get_configuration_options_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_installer_file(
        self,
        **kwargs: Any,
    ) -> bytes: ...

    def get_installer_file_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_license(
        self,
        **kwargs: Any,
    ) -> LicenseStatusOutputV1: ...

    def get_license_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_open_ping(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def get_open_ping_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_ping(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def get_ping_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_release_notes(
        self,
        **kwargs: Any,
    ) -> ReleaseNotesOutputV1: ...

    def get_release_notes_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_sent_emails(
        self,
        **kwargs: Any,
    ) -> SentEmailsListOutputV1: ...

    def get_sent_emails_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_server_load(
        self,
        **kwargs: Any,
    ) -> ServerLoadOutputV1: ...

    def get_server_load_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_server_status(
        self,
        **kwargs: Any,
    ) -> ServerStatusOutputV1: ...

    def get_server_status_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_supported_units(
        self,
        **kwargs: Any,
    ) -> SupportedUnitsOutputV1: ...

    def get_supported_units_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_thread_state(
        self,
        **kwargs: Any,
    ) -> str: ...

    def get_thread_state_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def import_license(
        self,
        **kwargs: Any,
    ) -> LicenseImporterOutputV1: ...

    def import_license_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def set_administrator_contact_information(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def set_administrator_contact_information_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def set_configuration_options(
        self,
        **kwargs: Any,
    ) -> ConfigurationOutputV1: ...

    def set_configuration_options_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def u_o_ms(
        self,
        **kwargs: Any,
    ) -> UnitsOfMeasureOutputV1: ...

    def u_o_ms_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_add_on_tool(
        self,
        **kwargs: Any,
    ) -> AddOnToolOutputV1: ...

    def update_add_on_tool_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
