# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class FolderSearchResultsV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _estimated_total_hits: int
    _facet_distribution: Dict[str, Any]
    _hits: List[Dict[str, Any]]
    _hits_per_page: int
    _page: int
    _path: Optional[List[ItemPreviewV1]]


    def __init__(
        self,
        estimated_total_hits: Optional[int] = None,
        facet_distribution: Optional[Dict[str, Any]] = None,
        hits: Optional[List[Dict[str, Any]]] = None,
        hits_per_page: Optional[int] = None,
        page: Optional[int] = None,
        path: Optional[List[ItemPreviewV1]] = None,
    ) -> None: ...

    @property
    def estimated_total_hits(self) -> int: ...

    @estimated_total_hits.setter
    def estimated_total_hits(self, estimated_total_hits: int) -> None: ...

    @property
    def facet_distribution(self) -> Dict[str, Any]: ...

    @facet_distribution.setter
    def facet_distribution(self, facet_distribution: Dict[str, Any]) -> None: ...

    @property
    def hits(self) -> List[Dict[str, Any]]: ...

    @hits.setter
    def hits(self, hits: List[Dict[str, Any]]) -> None: ...

    @property
    def hits_per_page(self) -> int: ...

    @hits_per_page.setter
    def hits_per_page(self, hits_per_page: int) -> None: ...

    @property
    def page(self) -> int: ...

    @page.setter
    def page(self, page: int) -> None: ...

    @property
    def path(self) -> Optional[List[ItemPreviewV1]]: ...

    @path.setter
    def path(self, path: Optional[List[ItemPreviewV1]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
