# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class DatasourceStatisticsV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _median_datasource_nanos: Optional[int]
    _median_queue_nanos: Optional[int]
    _median_total_nanos: Optional[int]
    _most_recent_cancellation: Optional[str]
    _most_recent_failure: Optional[str]
    _most_recent_success: Optional[str]
    _most_recent_timeout: Optional[str]
    _num_cancellations: Optional[int]
    _num_failures: Optional[int]
    _num_successes: Optional[int]
    _num_timeouts: Optional[int]
    _total_num_datums: Optional[int]


    def __init__(
        self,
        median_datasource_nanos: Optional[int] = None,
        median_queue_nanos: Optional[int] = None,
        median_total_nanos: Optional[int] = None,
        most_recent_cancellation: Optional[str] = None,
        most_recent_failure: Optional[str] = None,
        most_recent_success: Optional[str] = None,
        most_recent_timeout: Optional[str] = None,
        num_cancellations: Optional[int] = None,
        num_failures: Optional[int] = None,
        num_successes: Optional[int] = None,
        num_timeouts: Optional[int] = None,
        total_num_datums: Optional[int] = None,
    ) -> None: ...

    @property
    def median_datasource_nanos(self) -> Optional[int]: ...

    @median_datasource_nanos.setter
    def median_datasource_nanos(self, median_datasource_nanos: Optional[int]) -> None: ...

    @property
    def median_queue_nanos(self) -> Optional[int]: ...

    @median_queue_nanos.setter
    def median_queue_nanos(self, median_queue_nanos: Optional[int]) -> None: ...

    @property
    def median_total_nanos(self) -> Optional[int]: ...

    @median_total_nanos.setter
    def median_total_nanos(self, median_total_nanos: Optional[int]) -> None: ...

    @property
    def most_recent_cancellation(self) -> Optional[str]: ...

    @most_recent_cancellation.setter
    def most_recent_cancellation(self, most_recent_cancellation: Optional[str]) -> None: ...

    @property
    def most_recent_failure(self) -> Optional[str]: ...

    @most_recent_failure.setter
    def most_recent_failure(self, most_recent_failure: Optional[str]) -> None: ...

    @property
    def most_recent_success(self) -> Optional[str]: ...

    @most_recent_success.setter
    def most_recent_success(self, most_recent_success: Optional[str]) -> None: ...

    @property
    def most_recent_timeout(self) -> Optional[str]: ...

    @most_recent_timeout.setter
    def most_recent_timeout(self, most_recent_timeout: Optional[str]) -> None: ...

    @property
    def num_cancellations(self) -> Optional[int]: ...

    @num_cancellations.setter
    def num_cancellations(self, num_cancellations: Optional[int]) -> None: ...

    @property
    def num_failures(self) -> Optional[int]: ...

    @num_failures.setter
    def num_failures(self, num_failures: Optional[int]) -> None: ...

    @property
    def num_successes(self) -> Optional[int]: ...

    @num_successes.setter
    def num_successes(self, num_successes: Optional[int]) -> None: ...

    @property
    def num_timeouts(self) -> Optional[int]: ...

    @num_timeouts.setter
    def num_timeouts(self, num_timeouts: Optional[int]) -> None: ...

    @property
    def total_num_datums(self) -> Optional[int]: ...

    @total_num_datums.setter
    def total_num_datums(self, total_num_datums: Optional[int]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
