# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class AgentsApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def archive_agent(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def archive_agent_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_connection(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def archive_connection_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_connector(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def archive_connector_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def configured_directives(
        self,
        **kwargs: Any,
    ) -> ConfiguredDirectivesOutputV1: ...

    def configured_directives_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_or_update_agent(
        self,
        **kwargs: Any,
    ) -> AgentOutputV1: ...

    def create_or_update_agent_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_or_update_connection(
        self,
        **kwargs: Any,
    ) -> ConnectionOutputV1: ...

    def create_or_update_connection_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_or_update_connector(
        self,
        **kwargs: Any,
    ) -> ConnectorOutputV1: ...

    def create_or_update_connector_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_secret_for_connection(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_secret_for_connection_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_agent(
        self,
        **kwargs: Any,
    ) -> AgentOutputV1: ...

    def get_agent_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_agent_status(
        self,
        **kwargs: Any,
    ) -> List[AgentStatusV1]: ...

    def get_agent_status_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_connection(
        self,
        **kwargs: Any,
    ) -> ConnectionOutputV1: ...

    def get_connection_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_connections(
        self,
        **kwargs: Any,
    ) -> ConnectionsOutputV1: ...

    def get_connections_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_connector(
        self,
        **kwargs: Any,
    ) -> ConnectorOutputV1: ...

    def get_connector_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_connectors(
        self,
        **kwargs: Any,
    ) -> ConnectorsOutputV1: ...

    def get_connectors_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_datasources_status(
        self,
        **kwargs: Any,
    ) -> DatasourcesStatusOutputV1: ...

    def get_datasources_status_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_remote_update_directives(
        self,
        **kwargs: Any,
    ) -> RemoteAgentDirectivesOutputV1: ...

    def get_remote_update_directives_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def index(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def index_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def post_agent_status(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def post_agent_status_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def pre_provision(
        self,
        **kwargs: Any,
    ) -> PreProvisionOutputV1: ...

    def pre_provision_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def provision(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def provision_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def restart_agent(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def restart_agent_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def restart_connector(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def restart_connector_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def store_secret_for_connection(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def store_secret_for_connection_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_directive(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def update_directive_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_remote_agent_status(
        self,
        **kwargs: Any,
    ) -> RemoteAgentStatusOutputV1: ...

    def update_remote_agent_status_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
