# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AgentStatusV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _connections: List[ConnectionStatusV1]
    _datasource_access_stats: Optional[List[DatasourceAccessStatsV1]]
    _id: str
    _name: str
    _remote_agent: Optional[bool]
    _status: str
    _version: Optional[str]


    def __init__(
        self,
        connections: Optional[List[ConnectionStatusV1]] = None,
        datasource_access_stats: Optional[List[DatasourceAccessStatsV1]] = None,
        id: Optional[str] = None,
        name: Optional[str] = None,
        remote_agent: Optional[bool] = False,
        status: Optional[str] = None,
        version: Optional[str] = None,
    ) -> None: ...

    @property
    def connections(self) -> List[ConnectionStatusV1]: ...

    @connections.setter
    def connections(self, connections: List[ConnectionStatusV1]) -> None: ...

    @property
    def datasource_access_stats(self) -> Optional[List[DatasourceAccessStatsV1]]: ...

    @datasource_access_stats.setter
    def datasource_access_stats(self, datasource_access_stats: Optional[List[DatasourceAccessStatsV1]]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def remote_agent(self) -> Optional[bool]: ...

    @remote_agent.setter
    def remote_agent(self, remote_agent: Optional[bool]) -> None: ...

    @property
    def status(self) -> str: ...

    @status.setter
    def status(self, status: str) -> None: ...

    @property
    def version(self) -> Optional[str]: ...

    @version.setter
    def version(self, version: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
