# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ConditionOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _additional_properties: Optional[List[ScalarPropertyV1]]
    _capsule_id_property: Optional[str]
    _capsule_properties: Optional[List[CapsulePropertyOutputV1]]
    _data_id: Optional[str]
    _datasource_class: Optional[str]
    _datasource_id: Optional[str]
    _description: Optional[str]
    _effective_permissions: Optional[PermissionsV1]
    _formula: Optional[str]
    _id: str
    _is_archived: Optional[bool]
    _is_redacted: Optional[bool]
    _maximum_duration: Optional[str]
    _name: str
    _package_name: Optional[str]
    _parameters: Optional[List[FormulaParameterOutputV1]]
    _permissions_from_datasource: Optional[bool]
    _scoped_to: Optional[str]
    _security_string: Optional[str]
    _source_condition: Optional[str]
    _source_security_string: Optional[str]
    _status_message: Optional[str]
    _storage_location: Optional[str]
    _translation_key: Optional[str]
    _type: str
    _unit_of_measure: Optional[str]


    def __init__(
        self,
        additional_properties: Optional[List[ScalarPropertyV1]] = None,
        capsule_id_property: Optional[str] = None,
        capsule_properties: Optional[List[CapsulePropertyOutputV1]] = None,
        data_id: Optional[str] = None,
        datasource_class: Optional[str] = None,
        datasource_id: Optional[str] = None,
        description: Optional[str] = None,
        effective_permissions: Optional[PermissionsV1] = None,
        formula: Optional[str] = None,
        id: Optional[str] = None,
        is_archived: Optional[bool] = False,
        is_redacted: Optional[bool] = False,
        maximum_duration: Optional[str] = None,
        name: Optional[str] = None,
        package_name: Optional[str] = None,
        parameters: Optional[List[FormulaParameterOutputV1]] = None,
        permissions_from_datasource: Optional[bool] = False,
        scoped_to: Optional[str] = None,
        security_string: Optional[str] = None,
        source_condition: Optional[str] = None,
        source_security_string: Optional[str] = None,
        status_message: Optional[str] = None,
        storage_location: Optional[str] = None,
        translation_key: Optional[str] = None,
        type: Optional[str] = None,
        unit_of_measure: Optional[str] = None,
    ) -> None: ...

    @property
    def additional_properties(self) -> Optional[List[ScalarPropertyV1]]: ...

    @additional_properties.setter
    def additional_properties(self, additional_properties: Optional[List[ScalarPropertyV1]]) -> None: ...

    @property
    def capsule_id_property(self) -> Optional[str]: ...

    @capsule_id_property.setter
    def capsule_id_property(self, capsule_id_property: Optional[str]) -> None: ...

    @property
    def capsule_properties(self) -> Optional[List[CapsulePropertyOutputV1]]: ...

    @capsule_properties.setter
    def capsule_properties(self, capsule_properties: Optional[List[CapsulePropertyOutputV1]]) -> None: ...

    @property
    def data_id(self) -> Optional[str]: ...

    @data_id.setter
    def data_id(self, data_id: Optional[str]) -> None: ...

    @property
    def datasource_class(self) -> Optional[str]: ...

    @datasource_class.setter
    def datasource_class(self, datasource_class: Optional[str]) -> None: ...

    @property
    def datasource_id(self) -> Optional[str]: ...

    @datasource_id.setter
    def datasource_id(self, datasource_id: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def effective_permissions(self) -> Optional[PermissionsV1]: ...

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions: Optional[PermissionsV1]) -> None: ...

    @property
    def formula(self) -> Optional[str]: ...

    @formula.setter
    def formula(self, formula: Optional[str]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def is_redacted(self) -> Optional[bool]: ...

    @is_redacted.setter
    def is_redacted(self, is_redacted: Optional[bool]) -> None: ...

    @property
    def maximum_duration(self) -> Optional[str]: ...

    @maximum_duration.setter
    def maximum_duration(self, maximum_duration: Optional[str]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def package_name(self) -> Optional[str]: ...

    @package_name.setter
    def package_name(self, package_name: Optional[str]) -> None: ...

    @property
    def parameters(self) -> Optional[List[FormulaParameterOutputV1]]: ...

    @parameters.setter
    def parameters(self, parameters: Optional[List[FormulaParameterOutputV1]]) -> None: ...

    @property
    def permissions_from_datasource(self) -> Optional[bool]: ...

    @permissions_from_datasource.setter
    def permissions_from_datasource(self, permissions_from_datasource: Optional[bool]) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def security_string(self) -> Optional[str]: ...

    @security_string.setter
    def security_string(self, security_string: Optional[str]) -> None: ...

    @property
    def source_condition(self) -> Optional[str]: ...

    @source_condition.setter
    def source_condition(self, source_condition: Optional[str]) -> None: ...

    @property
    def source_security_string(self) -> Optional[str]: ...

    @source_security_string.setter
    def source_security_string(self, source_security_string: Optional[str]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def storage_location(self) -> Optional[str]: ...

    @storage_location.setter
    def storage_location(self, storage_location: Optional[str]) -> None: ...

    @property
    def translation_key(self) -> Optional[str]: ...

    @translation_key.setter
    def translation_key(self, translation_key: Optional[str]) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    @property
    def unit_of_measure(self) -> Optional[str]: ...

    @unit_of_measure.setter
    def unit_of_measure(self, unit_of_measure: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
