# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class StoredTableColumnInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _column_name: str
    _column_type: str
    _column_uom: Optional[str]
    _description: Optional[str]
    _is_hidden: Optional[bool]
    _is_indexed: Optional[bool]
    _sort_ascending: Optional[bool]
    _sort_index: Optional[int]


    def __init__(
        self,
        column_name: Optional[str] = None,
        column_type: Optional[str] = None,
        column_uom: Optional[str] = None,
        description: Optional[str] = None,
        is_hidden: Optional[bool] = None,
        is_indexed: Optional[bool] = None,
        sort_ascending: Optional[bool] = None,
        sort_index: Optional[int] = None,
    ) -> None: ...

    @property
    def column_name(self) -> str: ...

    @column_name.setter
    def column_name(self, column_name: str) -> None: ...

    @property
    def column_type(self) -> str: ...

    @column_type.setter
    def column_type(self, column_type: str) -> None: ...

    @property
    def column_uom(self) -> Optional[str]: ...

    @column_uom.setter
    def column_uom(self, column_uom: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def is_hidden(self) -> Optional[bool]: ...

    @is_hidden.setter
    def is_hidden(self, is_hidden: Optional[bool]) -> None: ...

    @property
    def is_indexed(self) -> Optional[bool]: ...

    @is_indexed.setter
    def is_indexed(self, is_indexed: Optional[bool]) -> None: ...

    @property
    def sort_ascending(self) -> Optional[bool]: ...

    @sort_ascending.setter
    def sort_ascending(self, sort_ascending: Optional[bool]) -> None: ...

    @property
    def sort_index(self) -> Optional[int]: ...

    @sort_index.setter
    def sort_index(self, sort_index: Optional[int]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
