# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class RadialGaugeRehydrationInstructionsInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'max': 'object',
        'series_identifier': 'str',
        'series_name': 'str',
        'time_key': 'str',
        'value_key': 'str'
    }

    attribute_map = {
        'max': 'max',
        'series_identifier': 'seriesIdentifier',
        'series_name': 'seriesName',
        'time_key': 'timeKey',
        'value_key': 'valueKey'
    }

    def __init__(self, max=None, series_identifier=None, series_name=None, time_key=None, value_key=None):
        """
        RadialGaugeRehydrationInstructionsInputV1 - a model defined in Swagger
        """

        self._max = None
        self._series_identifier = None
        self._series_name = None
        self._time_key = None
        self._value_key = None

        if max is not None:
          self.max = max
        if series_identifier is not None:
          self.series_identifier = series_identifier
        if series_name is not None:
          self.series_name = series_name
        if time_key is not None:
          self.time_key = time_key
        if value_key is not None:
          self.value_key = value_key

    @property
    def max(self):
        """
        Gets the max of this RadialGaugeRehydrationInstructionsInputV1.
        Optional max value or column key to use for the gauge

        :return: The max of this RadialGaugeRehydrationInstructionsInputV1.
        :rtype: object
        """
        return self._max

    @max.setter
    def max(self, max):
        """
        Sets the max of this RadialGaugeRehydrationInstructionsInputV1.
        Optional max value or column key to use for the gauge

        :param max: The max of this RadialGaugeRehydrationInstructionsInputV1.
        :type: object
        """

        self._max = max

    @property
    def series_identifier(self):
        """
        Gets the series_identifier of this RadialGaugeRehydrationInstructionsInputV1.
        Identifier that maps radial gauge data to chart options

        :return: The series_identifier of this RadialGaugeRehydrationInstructionsInputV1.
        :rtype: str
        """
        return self._series_identifier

    @series_identifier.setter
    def series_identifier(self, series_identifier):
        """
        Sets the series_identifier of this RadialGaugeRehydrationInstructionsInputV1.
        Identifier that maps radial gauge data to chart options

        :param series_identifier: The series_identifier of this RadialGaugeRehydrationInstructionsInputV1.
        :type: str
        """

        self._series_identifier = series_identifier

    @property
    def series_name(self):
        """
        Gets the series_name of this RadialGaugeRehydrationInstructionsInputV1.
        Display name to associate with the hydrated series values

        :return: The series_name of this RadialGaugeRehydrationInstructionsInputV1.
        :rtype: str
        """
        return self._series_name

    @series_name.setter
    def series_name(self, series_name):
        """
        Sets the series_name of this RadialGaugeRehydrationInstructionsInputV1.
        Display name to associate with the hydrated series values

        :param series_name: The series_name of this RadialGaugeRehydrationInstructionsInputV1.
        :type: str
        """

        self._series_name = series_name

    @property
    def time_key(self):
        """
        Gets the time_key of this RadialGaugeRehydrationInstructionsInputV1.
        The data column used as the time key for radial gauge rehydration

        :return: The time_key of this RadialGaugeRehydrationInstructionsInputV1.
        :rtype: str
        """
        return self._time_key

    @time_key.setter
    def time_key(self, time_key):
        """
        Sets the time_key of this RadialGaugeRehydrationInstructionsInputV1.
        The data column used as the time key for radial gauge rehydration

        :param time_key: The time_key of this RadialGaugeRehydrationInstructionsInputV1.
        :type: str
        """
        if time_key is None:
            raise ValueError("Invalid value for `time_key`, must not be `None`")

        self._time_key = time_key

    @property
    def value_key(self):
        """
        Gets the value_key of this RadialGaugeRehydrationInstructionsInputV1.
        The data column used as the value key for radial gauge rehydration

        :return: The value_key of this RadialGaugeRehydrationInstructionsInputV1.
        :rtype: str
        """
        return self._value_key

    @value_key.setter
    def value_key(self, value_key):
        """
        Sets the value_key of this RadialGaugeRehydrationInstructionsInputV1.
        The data column used as the value key for radial gauge rehydration

        :param value_key: The value_key of this RadialGaugeRehydrationInstructionsInputV1.
        :type: str
        """
        if value_key is None:
            raise ValueError("Invalid value for `value_key`, must not be `None`")

        self._value_key = value_key

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, RadialGaugeRehydrationInstructionsInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
