# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class TableDefinitionCSVUpdateInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _column_delimiter: str
    _header_row: int
    _name: str
    _upload_filename: str


    def __init__(
        self,
        column_delimiter: Optional[str] = None,
        header_row: Optional[int] = None,
        name: Optional[str] = None,
        upload_filename: Optional[str] = None,
    ) -> None: ...

    @property
    def column_delimiter(self) -> str: ...

    @column_delimiter.setter
    def column_delimiter(self, column_delimiter: str) -> None: ...

    @property
    def header_row(self) -> int: ...

    @header_row.setter
    def header_row(self, header_row: int) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def upload_filename(self) -> str: ...

    @upload_filename.setter
    def upload_filename(self, upload_filename: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
