# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class DatasourceStatusV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _datasource_class: Optional[str]
    _datasource_guid: Optional[str]
    _datasource_id: Optional[str]
    _datasource_name: Optional[str]
    _enabled: Optional[bool]
    _seeq_internal: Optional[bool]
    _statistics: Optional[DatasourceStatisticsV1]
    _stored_in_seeq: Optional[bool]


    def __init__(
        self,
        datasource_class: Optional[str] = None,
        datasource_guid: Optional[str] = None,
        datasource_id: Optional[str] = None,
        datasource_name: Optional[str] = None,
        enabled: Optional[bool] = False,
        seeq_internal: Optional[bool] = False,
        statistics: Optional[DatasourceStatisticsV1] = None,
        stored_in_seeq: Optional[bool] = False,
    ) -> None: ...

    @property
    def datasource_class(self) -> Optional[str]: ...

    @datasource_class.setter
    def datasource_class(self, datasource_class: Optional[str]) -> None: ...

    @property
    def datasource_guid(self) -> Optional[str]: ...

    @datasource_guid.setter
    def datasource_guid(self, datasource_guid: Optional[str]) -> None: ...

    @property
    def datasource_id(self) -> Optional[str]: ...

    @datasource_id.setter
    def datasource_id(self, datasource_id: Optional[str]) -> None: ...

    @property
    def datasource_name(self) -> Optional[str]: ...

    @datasource_name.setter
    def datasource_name(self, datasource_name: Optional[str]) -> None: ...

    @property
    def enabled(self) -> Optional[bool]: ...

    @enabled.setter
    def enabled(self, enabled: Optional[bool]) -> None: ...

    @property
    def seeq_internal(self) -> Optional[bool]: ...

    @seeq_internal.setter
    def seeq_internal(self, seeq_internal: Optional[bool]) -> None: ...

    @property
    def statistics(self) -> Optional[DatasourceStatisticsV1]: ...

    @statistics.setter
    def statistics(self, statistics: Optional[DatasourceStatisticsV1]) -> None: ...

    @property
    def stored_in_seeq(self) -> Optional[bool]: ...

    @stored_in_seeq.setter
    def stored_in_seeq(self, stored_in_seeq: Optional[bool]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
