# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class FormulaRunInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _continuation_token: Optional[str]
    _end: Optional[str]
    _formula: str
    _fragments: Optional[List[str]]
    _function: Optional[str]
    _items_to_scale_across: Optional[List[str]]
    _limit: Optional[int]
    _parameters: List[str]
    _reduce_formula: Optional[str]
    _root: Optional[str]
    _start: Optional[str]
    _time_format: Optional[str]


    def __init__(
        self,
        continuation_token: Optional[str] = None,
        end: Optional[str] = None,
        formula: Optional[str] = None,
        fragments: Optional[List[str]] = None,
        function: Optional[str] = None,
        items_to_scale_across: Optional[List[str]] = None,
        limit: Optional[int] = None,
        parameters: Optional[List[str]] = None,
        reduce_formula: Optional[str] = None,
        root: Optional[str] = None,
        start: Optional[str] = None,
        time_format: Optional[str] = None,
    ) -> None: ...

    @property
    def continuation_token(self) -> Optional[str]: ...

    @continuation_token.setter
    def continuation_token(self, continuation_token: Optional[str]) -> None: ...

    @property
    def end(self) -> Optional[str]: ...

    @end.setter
    def end(self, end: Optional[str]) -> None: ...

    @property
    def formula(self) -> str: ...

    @formula.setter
    def formula(self, formula: str) -> None: ...

    @property
    def fragments(self) -> Optional[List[str]]: ...

    @fragments.setter
    def fragments(self, fragments: Optional[List[str]]) -> None: ...

    @property
    def function(self) -> Optional[str]: ...

    @function.setter
    def function(self, function: Optional[str]) -> None: ...

    @property
    def items_to_scale_across(self) -> Optional[List[str]]: ...

    @items_to_scale_across.setter
    def items_to_scale_across(self, items_to_scale_across: Optional[List[str]]) -> None: ...

    @property
    def limit(self) -> Optional[int]: ...

    @limit.setter
    def limit(self, limit: Optional[int]) -> None: ...

    @property
    def parameters(self) -> List[str]: ...

    @parameters.setter
    def parameters(self, parameters: List[str]) -> None: ...

    @property
    def reduce_formula(self) -> Optional[str]: ...

    @reduce_formula.setter
    def reduce_formula(self, reduce_formula: Optional[str]) -> None: ...

    @property
    def root(self) -> Optional[str]: ...

    @root.setter
    def root(self, root: Optional[str]) -> None: ...

    @property
    def start(self) -> Optional[str]: ...

    @start.setter
    def start(self, start: Optional[str]) -> None: ...

    @property
    def time_format(self) -> Optional[str]: ...

    @time_format.setter
    def time_format(self, time_format: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
