# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class CommentCategoryOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _created_at: Optional[str]
    _creator_id: Optional[str]
    _help_text: Optional[str]
    _icon: Optional[str]
    _id: Optional[str]
    _name: Optional[str]
    _title: Optional[str]
    _updated_at: Optional[str]


    def __init__(
        self,
        created_at: Optional[str] = None,
        creator_id: Optional[str] = None,
        help_text: Optional[str] = None,
        icon: Optional[str] = None,
        id: Optional[str] = None,
        name: Optional[str] = None,
        title: Optional[str] = None,
        updated_at: Optional[str] = None,
    ) -> None: ...

    @property
    def created_at(self) -> Optional[str]: ...

    @created_at.setter
    def created_at(self, created_at: Optional[str]) -> None: ...

    @property
    def creator_id(self) -> Optional[str]: ...

    @creator_id.setter
    def creator_id(self, creator_id: Optional[str]) -> None: ...

    @property
    def help_text(self) -> Optional[str]: ...

    @help_text.setter
    def help_text(self, help_text: Optional[str]) -> None: ...

    @property
    def icon(self) -> Optional[str]: ...

    @icon.setter
    def icon(self, icon: Optional[str]) -> None: ...

    @property
    def id(self) -> Optional[str]: ...

    @id.setter
    def id(self, id: Optional[str]) -> None: ...

    @property
    def name(self) -> Optional[str]: ...

    @name.setter
    def name(self, name: Optional[str]) -> None: ...

    @property
    def title(self) -> Optional[str]: ...

    @title.setter
    def title(self, title: Optional[str]) -> None: ...

    @property
    def updated_at(self) -> Optional[str]: ...

    @updated_at.setter
    def updated_at(self, updated_at: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
