# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class DatasourcesStatusOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _agent_orchestrators: Optional[List[AgentOrchestratorOutputV1]]
    _agents: Optional[List[AgentStatusOutputV1]]
    _connected_connections_count: int
    _connected_datasources_count: int
    _datasources: Optional[List[DatasourceSummaryStatusOutputV1]]
    _total_connections_count: int
    _total_datasources_count: int


    def __init__(
        self,
        agent_orchestrators: Optional[List[AgentOrchestratorOutputV1]] = None,
        agents: Optional[List[AgentStatusOutputV1]] = None,
        connected_connections_count: Optional[int] = None,
        connected_datasources_count: Optional[int] = None,
        datasources: Optional[List[DatasourceSummaryStatusOutputV1]] = None,
        total_connections_count: Optional[int] = None,
        total_datasources_count: Optional[int] = None,
    ) -> None: ...

    @property
    def agent_orchestrators(self) -> Optional[List[AgentOrchestratorOutputV1]]: ...

    @agent_orchestrators.setter
    def agent_orchestrators(self, agent_orchestrators: Optional[List[AgentOrchestratorOutputV1]]) -> None: ...

    @property
    def agents(self) -> Optional[List[AgentStatusOutputV1]]: ...

    @agents.setter
    def agents(self, agents: Optional[List[AgentStatusOutputV1]]) -> None: ...

    @property
    def connected_connections_count(self) -> int: ...

    @connected_connections_count.setter
    def connected_connections_count(self, connected_connections_count: int) -> None: ...

    @property
    def connected_datasources_count(self) -> int: ...

    @connected_datasources_count.setter
    def connected_datasources_count(self, connected_datasources_count: int) -> None: ...

    @property
    def datasources(self) -> Optional[List[DatasourceSummaryStatusOutputV1]]: ...

    @datasources.setter
    def datasources(self, datasources: Optional[List[DatasourceSummaryStatusOutputV1]]) -> None: ...

    @property
    def total_connections_count(self) -> int: ...

    @total_connections_count.setter
    def total_connections_count(self, total_connections_count: int) -> None: ...

    @property
    def total_datasources_count(self) -> int: ...

    @total_datasources_count.setter
    def total_datasources_count(self, total_datasources_count: int) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
