# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class DerivedFeatureV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'id': 'str',
        'is_output': 'bool',
        'name': 'str',
        'output_type': 'str',
        'rules': 'list[FeatureRuleV1]'
    }

    attribute_map = {
        'description': 'description',
        'id': 'id',
        'is_output': 'isOutput',
        'name': 'name',
        'output_type': 'outputType',
        'rules': 'rules'
    }

    def __init__(self, description=None, id=None, is_output=None, name=None, output_type=None, rules=None):
        """
        DerivedFeatureV1 - a model defined in Swagger
        """

        self._description = None
        self._id = None
        self._is_output = None
        self._name = None
        self._output_type = None
        self._rules = None

        if description is not None:
          self.description = description
        if id is not None:
          self.id = id
        if is_output is not None:
          self.is_output = is_output
        if name is not None:
          self.name = name
        if output_type is not None:
          self.output_type = output_type
        if rules is not None:
          self.rules = rules

    @property
    def description(self):
        """
        Gets the description of this DerivedFeatureV1.
        Description of the feature

        :return: The description of this DerivedFeatureV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this DerivedFeatureV1.
        Description of the feature

        :param description: The description of this DerivedFeatureV1.
        :type: str
        """

        self._description = description

    @property
    def id(self):
        """
        Gets the id of this DerivedFeatureV1.
        Feature ID; omit on create

        :return: The id of this DerivedFeatureV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DerivedFeatureV1.
        Feature ID; omit on create

        :param id: The id of this DerivedFeatureV1.
        :type: str
        """

        self._id = id

    @property
    def is_output(self):
        """
        Gets the is_output of this DerivedFeatureV1.
        Indicates if this feature is an output

        :return: The is_output of this DerivedFeatureV1.
        :rtype: bool
        """
        return self._is_output

    @is_output.setter
    def is_output(self, is_output):
        """
        Sets the is_output of this DerivedFeatureV1.
        Indicates if this feature is an output

        :param is_output: The is_output of this DerivedFeatureV1.
        :type: bool
        """

        self._is_output = is_output

    @property
    def name(self):
        """
        Gets the name of this DerivedFeatureV1.
        Name of the feature

        :return: The name of this DerivedFeatureV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DerivedFeatureV1.
        Name of the feature

        :param name: The name of this DerivedFeatureV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def output_type(self):
        """
        Gets the output_type of this DerivedFeatureV1.
        Type of the feature output

        :return: The output_type of this DerivedFeatureV1.
        :rtype: str
        """
        return self._output_type

    @output_type.setter
    def output_type(self, output_type):
        """
        Sets the output_type of this DerivedFeatureV1.
        Type of the feature output

        :param output_type: The output_type of this DerivedFeatureV1.
        :type: str
        """
        if output_type is None:
            raise ValueError("Invalid value for `output_type`, must not be `None`")

        self._output_type = output_type

    @property
    def rules(self):
        """
        Gets the rules of this DerivedFeatureV1.
        The list of rules that determine the resulting value of a feature. At least one rule is required

        :return: The rules of this DerivedFeatureV1.
        :rtype: list[FeatureRuleV1]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """
        Sets the rules of this DerivedFeatureV1.
        The list of rules that determine the resulting value of a feature. At least one rule is required

        :param rules: The rules of this DerivedFeatureV1.
        :type: list[FeatureRuleV1]
        """
        if rules is None:
            raise ValueError("Invalid value for `rules`, must not be `None`")

        self._rules = rules

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, DerivedFeatureV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
