# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class DirectItemIdsSourceV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'asset_id': 'str',
        'condition_stats': 'list[ConditionTableStatInputForDirectItemsV1]',
        'item_ids': 'list[str]'
    }

    attribute_map = {
        'asset_id': 'assetId',
        'condition_stats': 'conditionStats',
        'item_ids': 'itemIds'
    }

    def __init__(self, asset_id=None, condition_stats=None, item_ids=None):
        """
        DirectItemIdsSourceV1 - a model defined in Swagger
        """

        self._asset_id = None
        self._condition_stats = None
        self._item_ids = None

        if asset_id is not None:
          self.asset_id = asset_id
        if condition_stats is not None:
          self.condition_stats = condition_stats
        if item_ids is not None:
          self.item_ids = item_ids

    @property
    def asset_id(self):
        """
        Gets the asset_id of this DirectItemIdsSourceV1.
        Optional root asset ID to run conditions across its children

        :return: The asset_id of this DirectItemIdsSourceV1.
        :rtype: str
        """
        return self._asset_id

    @asset_id.setter
    def asset_id(self, asset_id):
        """
        Sets the asset_id of this DirectItemIdsSourceV1.
        Optional root asset ID to run conditions across its children

        :param asset_id: The asset_id of this DirectItemIdsSourceV1.
        :type: str
        """

        self._asset_id = asset_id

    @property
    def condition_stats(self):
        """
        Gets the condition_stats of this DirectItemIdsSourceV1.
        The list of statistics to calculate for the condition items

        :return: The condition_stats of this DirectItemIdsSourceV1.
        :rtype: list[ConditionTableStatInputForDirectItemsV1]
        """
        return self._condition_stats

    @condition_stats.setter
    def condition_stats(self, condition_stats):
        """
        Sets the condition_stats of this DirectItemIdsSourceV1.
        The list of statistics to calculate for the condition items

        :param condition_stats: The condition_stats of this DirectItemIdsSourceV1.
        :type: list[ConditionTableStatInputForDirectItemsV1]
        """

        self._condition_stats = condition_stats

    @property
    def item_ids(self):
        """
        Gets the item_ids of this DirectItemIdsSourceV1.
        List of condition and condition metric item IDs to run the table across

        :return: The item_ids of this DirectItemIdsSourceV1.
        :rtype: list[str]
        """
        return self._item_ids

    @item_ids.setter
    def item_ids(self, item_ids):
        """
        Sets the item_ids of this DirectItemIdsSourceV1.
        List of condition and condition metric item IDs to run the table across

        :param item_ids: The item_ids of this DirectItemIdsSourceV1.
        :type: list[str]
        """
        if item_ids is None:
            raise ValueError("Invalid value for `item_ids`, must not be `None`")

        self._item_ids = item_ids

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, DirectItemIdsSourceV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
