# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class BoardTimeframeComparisonMetricOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'baseline_value': 'float',
        'column': 'str',
        'current_value': 'float',
        'delta': 'float',
        'metric': 'str',
        'percent_change': 'float'
    }

    attribute_map = {
        'baseline_value': 'baselineValue',
        'column': 'column',
        'current_value': 'currentValue',
        'delta': 'delta',
        'metric': 'metric',
        'percent_change': 'percentChange'
    }

    def __init__(self, baseline_value=None, column=None, current_value=None, delta=None, metric=None, percent_change=None):
        """
        BoardTimeframeComparisonMetricOutputV1 - a model defined in Swagger
        """

        self._baseline_value = None
        self._column = None
        self._current_value = None
        self._delta = None
        self._metric = None
        self._percent_change = None

        if baseline_value is not None:
          self.baseline_value = baseline_value
        if column is not None:
          self.column = column
        if current_value is not None:
          self.current_value = current_value
        if delta is not None:
          self.delta = delta
        if metric is not None:
          self.metric = metric
        if percent_change is not None:
          self.percent_change = percent_change

    @property
    def baseline_value(self):
        """
        Gets the baseline_value of this BoardTimeframeComparisonMetricOutputV1.
        Baseline value for the metric

        :return: The baseline_value of this BoardTimeframeComparisonMetricOutputV1.
        :rtype: float
        """
        return self._baseline_value

    @baseline_value.setter
    def baseline_value(self, baseline_value):
        """
        Sets the baseline_value of this BoardTimeframeComparisonMetricOutputV1.
        Baseline value for the metric

        :param baseline_value: The baseline_value of this BoardTimeframeComparisonMetricOutputV1.
        :type: float
        """

        self._baseline_value = baseline_value

    @property
    def column(self):
        """
        Gets the column of this BoardTimeframeComparisonMetricOutputV1.
        Column name being compared

        :return: The column of this BoardTimeframeComparisonMetricOutputV1.
        :rtype: str
        """
        return self._column

    @column.setter
    def column(self, column):
        """
        Sets the column of this BoardTimeframeComparisonMetricOutputV1.
        Column name being compared

        :param column: The column of this BoardTimeframeComparisonMetricOutputV1.
        :type: str
        """
        if column is None:
            raise ValueError("Invalid value for `column`, must not be `None`")

        self._column = column

    @property
    def current_value(self):
        """
        Gets the current_value of this BoardTimeframeComparisonMetricOutputV1.
        Current value for the metric

        :return: The current_value of this BoardTimeframeComparisonMetricOutputV1.
        :rtype: float
        """
        return self._current_value

    @current_value.setter
    def current_value(self, current_value):
        """
        Sets the current_value of this BoardTimeframeComparisonMetricOutputV1.
        Current value for the metric

        :param current_value: The current_value of this BoardTimeframeComparisonMetricOutputV1.
        :type: float
        """

        self._current_value = current_value

    @property
    def delta(self):
        """
        Gets the delta of this BoardTimeframeComparisonMetricOutputV1.
        Delta between current and baseline

        :return: The delta of this BoardTimeframeComparisonMetricOutputV1.
        :rtype: float
        """
        return self._delta

    @delta.setter
    def delta(self, delta):
        """
        Sets the delta of this BoardTimeframeComparisonMetricOutputV1.
        Delta between current and baseline

        :param delta: The delta of this BoardTimeframeComparisonMetricOutputV1.
        :type: float
        """

        self._delta = delta

    @property
    def metric(self):
        """
        Gets the metric of this BoardTimeframeComparisonMetricOutputV1.
        Metric used for comparison (mean|sum|min|max)

        :return: The metric of this BoardTimeframeComparisonMetricOutputV1.
        :rtype: str
        """
        return self._metric

    @metric.setter
    def metric(self, metric):
        """
        Sets the metric of this BoardTimeframeComparisonMetricOutputV1.
        Metric used for comparison (mean|sum|min|max)

        :param metric: The metric of this BoardTimeframeComparisonMetricOutputV1.
        :type: str
        """
        if metric is None:
            raise ValueError("Invalid value for `metric`, must not be `None`")

        self._metric = metric

    @property
    def percent_change(self):
        """
        Gets the percent_change of this BoardTimeframeComparisonMetricOutputV1.
        Percent change from baseline (null if baseline is zero)

        :return: The percent_change of this BoardTimeframeComparisonMetricOutputV1.
        :rtype: float
        """
        return self._percent_change

    @percent_change.setter
    def percent_change(self, percent_change):
        """
        Sets the percent_change of this BoardTimeframeComparisonMetricOutputV1.
        Percent change from baseline (null if baseline is zero)

        :param percent_change: The percent_change of this BoardTimeframeComparisonMetricOutputV1.
        :type: float
        """

        self._percent_change = percent_change

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, BoardTimeframeComparisonMetricOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
