# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ViewColumnFilterInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'filter_group_label': 'int',
        'filter_operation': 'str',
        'filter_value': 'str'
    }

    attribute_map = {
        'filter_group_label': 'filterGroupLabel',
        'filter_operation': 'filterOperation',
        'filter_value': 'filterValue'
    }

    def __init__(self, filter_group_label=None, filter_operation=None, filter_value=None):
        """
        ViewColumnFilterInputV1 - a model defined in Swagger
        """

        self._filter_group_label = None
        self._filter_operation = None
        self._filter_value = None

        if filter_group_label is not None:
          self.filter_group_label = filter_group_label
        if filter_operation is not None:
          self.filter_operation = filter_operation
        if filter_value is not None:
          self.filter_value = filter_value

    @property
    def filter_group_label(self):
        """
        Gets the filter_group_label of this ViewColumnFilterInputV1.
        The integer label for referencing this filter in the Hierarchy's filter grouping. If the Hierarchy has a filter grouping defined, this value is required

        :return: The filter_group_label of this ViewColumnFilterInputV1.
        :rtype: int
        """
        return self._filter_group_label

    @filter_group_label.setter
    def filter_group_label(self, filter_group_label):
        """
        Sets the filter_group_label of this ViewColumnFilterInputV1.
        The integer label for referencing this filter in the Hierarchy's filter grouping. If the Hierarchy has a filter grouping defined, this value is required

        :param filter_group_label: The filter_group_label of this ViewColumnFilterInputV1.
        :type: int
        """

        self._filter_group_label = filter_group_label

    @property
    def filter_operation(self):
        """
        Gets the filter_operation of this ViewColumnFilterInputV1.
        The filter operation to be applied to this column. This operation determines how the filterValue is applied to the column data. If the filterOperation is `IS_NULL` or `IS_NOT_NULL`, the filterValue must not be provided.

        :return: The filter_operation of this ViewColumnFilterInputV1.
        :rtype: str
        """
        return self._filter_operation

    @filter_operation.setter
    def filter_operation(self, filter_operation):
        """
        Sets the filter_operation of this ViewColumnFilterInputV1.
        The filter operation to be applied to this column. This operation determines how the filterValue is applied to the column data. If the filterOperation is `IS_NULL` or `IS_NOT_NULL`, the filterValue must not be provided.

        :param filter_operation: The filter_operation of this ViewColumnFilterInputV1.
        :type: str
        """
        if filter_operation is None:
            raise ValueError("Invalid value for `filter_operation`, must not be `None`")

        self._filter_operation = filter_operation

    @property
    def filter_value(self):
        """
        Gets the filter_value of this ViewColumnFilterInputV1.
        The filter value for this column. If not provided, the filterOperation must be `IS_NULL` or `IS_NOT_NULL`.

        :return: The filter_value of this ViewColumnFilterInputV1.
        :rtype: str
        """
        return self._filter_value

    @filter_value.setter
    def filter_value(self, filter_value):
        """
        Sets the filter_value of this ViewColumnFilterInputV1.
        The filter value for this column. If not provided, the filterOperation must be `IS_NULL` or `IS_NOT_NULL`.

        :param filter_value: The filter_value of this ViewColumnFilterInputV1.
        :type: str
        """

        self._filter_value = filter_value

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ViewColumnFilterInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
