# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class EmailerConfigurationOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _max_number_of_attachments: int
    _max_attachments_size_in_mb: float
    _allowed_attachment_types: List[str]


    def __init__(
        self,
        max_number_of_attachments: Optional[int] = None,
        max_attachments_size_in_mb: Optional[float] = None,
        allowed_attachment_types: Optional[List[str]] = None,
    ) -> None: ...

    @property
    def max_number_of_attachments(self) -> int: ...

    @max_number_of_attachments.setter
    def max_number_of_attachments(self, max_number_of_attachments: int) -> None: ...

    @property
    def max_attachments_size_in_mb(self) -> float: ...

    @max_attachments_size_in_mb.setter
    def max_attachments_size_in_mb(self, max_attachments_size_in_mb: float) -> None: ...

    @property
    def allowed_attachment_types(self) -> List[str]: ...

    @allowed_attachment_types.setter
    def allowed_attachment_types(self, allowed_attachment_types: List[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
