# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class BoardTimeframeComparisonInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _absolute_threshold: Optional[float]
    _applied_filters: Optional[List[BoardFilterInputV1]]
    _baseline_end: str
    _baseline_start: str
    _current_end: str
    _current_start: str
    _limit: Optional[int]
    _metric: Optional[str]
    _percent_threshold: Optional[float]
    _tile_ids: Optional[List[str]]


    def __init__(
        self,
        absolute_threshold: Optional[float] = None,
        applied_filters: Optional[List[BoardFilterInputV1]] = None,
        baseline_end: Optional[str] = None,
        baseline_start: Optional[str] = None,
        current_end: Optional[str] = None,
        current_start: Optional[str] = None,
        limit: Optional[int] = None,
        metric: Optional[str] = None,
        percent_threshold: Optional[float] = None,
        tile_ids: Optional[List[str]] = None,
    ) -> None: ...

    @property
    def absolute_threshold(self) -> Optional[float]: ...

    @absolute_threshold.setter
    def absolute_threshold(self, absolute_threshold: Optional[float]) -> None: ...

    @property
    def applied_filters(self) -> Optional[List[BoardFilterInputV1]]: ...

    @applied_filters.setter
    def applied_filters(self, applied_filters: Optional[List[BoardFilterInputV1]]) -> None: ...

    @property
    def baseline_end(self) -> str: ...

    @baseline_end.setter
    def baseline_end(self, baseline_end: str) -> None: ...

    @property
    def baseline_start(self) -> str: ...

    @baseline_start.setter
    def baseline_start(self, baseline_start: str) -> None: ...

    @property
    def current_end(self) -> str: ...

    @current_end.setter
    def current_end(self, current_end: str) -> None: ...

    @property
    def current_start(self) -> str: ...

    @current_start.setter
    def current_start(self, current_start: str) -> None: ...

    @property
    def limit(self) -> Optional[int]: ...

    @limit.setter
    def limit(self, limit: Optional[int]) -> None: ...

    @property
    def metric(self) -> Optional[str]: ...

    @metric.setter
    def metric(self, metric: Optional[str]) -> None: ...

    @property
    def percent_threshold(self) -> Optional[float]: ...

    @percent_threshold.setter
    def percent_threshold(self, percent_threshold: Optional[float]) -> None: ...

    @property
    def tile_ids(self) -> Optional[List[str]]: ...

    @tile_ids.setter
    def tile_ids(self, tile_ids: Optional[List[str]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
