# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ProjectInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _configuration: Optional[List[ScalarPropertyV1]]
    _description: Optional[str]
    _folder_id: Optional[str]
    _name: str
    _owner_id: Optional[str]
    _project_type: Optional[str]
    _resource_size: Optional[str]
    _startup_environment: Optional[str]


    def __init__(
        self,
        configuration: Optional[List[ScalarPropertyV1]] = None,
        description: Optional[str] = None,
        folder_id: Optional[str] = None,
        name: Optional[str] = None,
        owner_id: Optional[str] = None,
        project_type: Optional[str] = None,
        resource_size: Optional[str] = None,
        startup_environment: Optional[str] = None,
    ) -> None: ...

    @property
    def configuration(self) -> Optional[List[ScalarPropertyV1]]: ...

    @configuration.setter
    def configuration(self, configuration: Optional[List[ScalarPropertyV1]]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def folder_id(self) -> Optional[str]: ...

    @folder_id.setter
    def folder_id(self, folder_id: Optional[str]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def owner_id(self) -> Optional[str]: ...

    @owner_id.setter
    def owner_id(self, owner_id: Optional[str]) -> None: ...

    @property
    def project_type(self) -> Optional[str]: ...

    @project_type.setter
    def project_type(self, project_type: Optional[str]) -> None: ...

    @property
    def resource_size(self) -> Optional[str]: ...

    @resource_size.setter
    def resource_size(self, resource_size: Optional[str]) -> None: ...

    @property
    def startup_environment(self) -> Optional[str]: ...

    @startup_environment.setter
    def startup_environment(self, startup_environment: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
