# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class ContentApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def archive_asset_selection(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def archive_asset_selection_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_content(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def archive_content_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_date_range(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def archive_date_range_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def clear_image_cache(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def clear_image_cache_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_asset_selection(
        self,
        **kwargs: Any,
    ) -> AssetSelectionOutputV1: ...

    def create_asset_selection_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_content(
        self,
        **kwargs: Any,
    ) -> ContentOutputV1: ...

    def create_content_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_date_range(
        self,
        **kwargs: Any,
    ) -> DateRangeOutputV1: ...

    def create_date_range_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_asset_selection(
        self,
        **kwargs: Any,
    ) -> AssetSelectionOutputV1: ...

    def get_asset_selection_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_content(
        self,
        **kwargs: Any,
    ) -> ContentOutputV1: ...

    def get_content_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_content_items(
        self,
        **kwargs: Any,
    ) -> GetContentItemsOutputV1: ...

    def get_content_items_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_content_items_for_date_range(
        self,
        **kwargs: Any,
    ) -> GetContentItemsOutputV1: ...

    def get_content_items_for_date_range_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_contents_with_all_metadata(
        self,
        **kwargs: Any,
    ) -> ContentWithMetadataListOutputV1: ...

    def get_contents_with_all_metadata_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_date_range(
        self,
        **kwargs: Any,
    ) -> DateRangeOutputV1: ...

    def get_date_range_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_date_ranges(
        self,
        **kwargs: Any,
    ) -> GetDateRangesOutputV1: ...

    def get_date_ranges_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_image(
        self,
        **kwargs: Any,
    ) -> bytes: ...

    def get_image_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_notifiable_reports(
        self,
        **kwargs: Any,
    ) -> NotifiableReportOutputListV1: ...

    def get_notifiable_reports_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_react_blob(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_react_blob_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_schedulable_statistics(
        self,
        **kwargs: Any,
    ) -> SchedulableAdminListOutputV1: ...

    def get_schedulable_statistics_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_schedulable_summary(
        self,
        **kwargs: Any,
    ) -> SchedulableSummaryWeekOutputV1: ...

    def get_schedulable_summary_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def preview_content(
        self,
        **kwargs: Any,
    ) -> bytes: ...

    def preview_content_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def redirect_to_source_worksheet(
        self,
        **kwargs: Any,
    ) -> str: ...

    def redirect_to_source_worksheet_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_asset_selection(
        self,
        **kwargs: Any,
    ) -> AssetSelectionOutputV1: ...

    def update_asset_selection_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_content(
        self,
        **kwargs: Any,
    ) -> ContentOutputV1: ...

    def update_content_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_date_range(
        self,
        **kwargs: Any,
    ) -> DateRangeOutputV1: ...

    def update_date_range_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_last_viewed_time(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def update_last_viewed_time_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
