# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class SignalsApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def add_samples(
        self,
        **kwargs: Any,
    ) -> SamplesOutputV1: ...

    def add_samples_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def add_samples_by_data_id(
        self,
        **kwargs: Any,
    ) -> SamplesOutputV1: ...

    def add_samples_by_data_id_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_signal(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def archive_signal_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_signal_by_data_id(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def archive_signal_by_data_id_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_signal(
        self,
        **kwargs: Any,
    ) -> SignalOutputV1: ...

    def create_signal_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_samples(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_samples_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_sample(
        self,
        **kwargs: Any,
    ) -> GetSampleOutputV1: ...

    def get_sample_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_sample_by_data_id(
        self,
        **kwargs: Any,
    ) -> GetSampleOutputV1: ...

    def get_sample_by_data_id_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_samples(
        self,
        **kwargs: Any,
    ) -> GetSamplesOutputV1: ...

    def get_samples_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_samples_by_data_id(
        self,
        **kwargs: Any,
    ) -> GetSamplesOutputV1: ...

    def get_samples_by_data_id_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_signal(
        self,
        **kwargs: Any,
    ) -> SignalOutputV1: ...

    def get_signal_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_signal_by_data_id(
        self,
        **kwargs: Any,
    ) -> SignalOutputV1: ...

    def get_signal_by_data_id_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_signals(
        self,
        **kwargs: Any,
    ) -> GetSignalsOutputV1: ...

    def get_signals_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def put_samples(
        self,
        **kwargs: Any,
    ) -> SamplesOutputV1: ...

    def put_samples_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def put_samples_by_data_id(
        self,
        **kwargs: Any,
    ) -> SamplesOutputV1: ...

    def put_samples_by_data_id_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def put_signal(
        self,
        **kwargs: Any,
    ) -> SignalOutputV1: ...

    def put_signal_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def put_signal_by_data_id(
        self,
        **kwargs: Any,
    ) -> SignalOutputV1: ...

    def put_signal_by_data_id_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def put_signals(
        self,
        **kwargs: Any,
    ) -> ItemBatchOutputV1: ...

    def put_signals_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
